@use "./tokens";

@import "tailwindcss" source(none);
@source "../../../../../vendor/cpcreation/viti-theme-legacytheme3/templates";
@source "../../../../../vendor/cpcreation/viti-theme-legacytheme3/assets/**/*.js";
@source "../../../../../vendor/cpcreation/viti-theme-legacytheme3/assets/**/*.css";
@source "../../../../../vendor/cpcreation/viti-theme-legacytheme3/assets/**/*.scss";
:root {
    --theme-gold: #d3ad74;
    --theme-gold-soft: #f4d49d;
    --theme-gray: #6b6b6a;
    --theme-dark: #3c3c3b;
    --theme-black: #141414;
    --theme-white: #ffffff;
    --theme-container: 1200px;
}

/* Age verification and error pages */
.theme-age-gate {
    z-index: 180;
    background: rgba(20, 20, 20, 0.96);
    color: var(--theme-white);
}

.theme-age-gate__panel {
    border: 1px solid rgba(211, 173, 116, 0.72);
    border-left-width: 4px;
    background: var(--theme-dark);
    box-shadow: 0 32px 90px rgba(0, 0, 0, 0.62);
}

.theme-age-gate__brand,
.theme-age-gate__label {
    color: var(--theme-gold);
}

.theme-age-gate__title {
    color: var(--theme-white);
}

.theme-age-gate__introduction,
.theme-age-gate__hint,
.theme-age-gate__privacy {
    color: rgba(255, 255, 255, 0.74);
}

.theme-age-gate__select,
.theme-age-gate__year {
    border: 1px solid var(--theme-gold);
    border-radius: 0;
    background: var(--theme-black);
    color: var(--theme-white);
    box-shadow: none;
}

.theme-age-gate__select:focus,
.theme-age-gate__year:focus {
    border-color: var(--theme-gold-soft);
    outline: 2px solid rgba(211, 173, 116, 0.3);
    outline-offset: 0;
}

.theme-age-gate__year::placeholder {
    color: rgba(255, 255, 255, 0.48);
}

.theme-age-gate__error {
    border-color: #f1b7a6;
    border-left-width: 4px;
    background: rgba(94, 35, 28, 0.55);
    color: #f1b7a6;
}

.theme-error-page {
    min-height: 100dvh;
    margin: 0;
    background: var(--theme-black);
    color: var(--theme-white);
}

.theme-error-page__main {
    min-height: 100dvh;
}

.theme-error-page__panel {
    border: 1px solid rgba(211, 173, 116, 0.55);
    border-left-width: 4px;
    border-left-color: var(--theme-gold);
    background: var(--theme-dark);
    box-shadow: 0 32px 90px rgba(0, 0, 0, 0.62);
}

.theme-error-page__code {
    color: var(--theme-gold);
}

.theme-error-page__title {
    color: var(--theme-white);
}

.theme-error-page__description {
    color: rgba(255, 255, 255, 0.75);
}

.theme-error-page__action {
    display: inline-flex;
}

/* Product reviews */
.theme-shop-product-card__reviews {
    display: inline-flex;
    width: fit-content;
    align-items: center;
    justify-content: center;
    gap: 7px;
    border: 0;
    background: transparent;
    padding: 0;
    color: var(--theme-gold-soft);
    font-family: var(--font-sans);
    font-size: 13px;
    text-decoration: underline;
    text-decoration-color: transparent;
    text-underline-offset: 4px;
    transition: color 160ms ease, text-decoration-color 160ms ease;
}

.theme-shop-product-card__reviews:hover,
.theme-shop-product-card__reviews:focus-visible {
    color: var(--theme-white);
    text-decoration-color: currentColor;
}

.theme-shop-product-card__review-star {
    position: relative;
    display: inline-block;
    width: 19px;
    height: 19px;
    color: var(--theme-gold);
}

.theme-shop-product-card__review-star > svg,
.theme-shop-product-card__review-star > span {
    position: absolute;
    inset: 0;
}

.theme-shop-product-card__review-star > span {
    overflow: hidden;
}

.theme-shop-product-card__review-star svg {
    width: 19px;
    max-width: none;
    height: 19px;
}

.theme-review-page,
.theme-reviews {
    background: var(--theme-black);
    color: var(--theme-white);
}

.theme-review-page {
    min-height: 65vh;
    padding: 72px 0 96px;
}

.theme-review-page__container {
    max-width: 880px;
}

.theme-review-page__header {
    margin-bottom: 38px;
    text-align: center;
}

.theme-review-page__header h1,
.theme-review-page__header h2 {
    margin: 0;
    color: var(--theme-white);
    font-size: clamp(30px, 5vw, 48px);
    font-weight: 300;
}

.theme-review-page__header p:not(.theme-eyebrow) {
    max-width: 680px;
    margin: 16px auto 0;
    color: rgba(255, 255, 255, 0.78);
}

.theme-review-page__footer-link {
    margin-top: 32px;
    text-align: center;
}

.theme-review-page a:not(.theme-button-fill):not(.theme-button-stroke),
.theme-reviews a {
    color: var(--theme-gold-soft);
    text-decoration: underline;
    text-underline-offset: 4px;
}

.theme-review-form .theme-auth-form,
.theme-review-page > .theme-container > .theme-auth-form {
    padding: 28px;
    border-left: 4px solid var(--theme-gold);
    background: var(--theme-dark);
}

.theme-review-form__submit {
    justify-self: start;
}

.theme-review-status,
.theme-review-report-card {
    margin-bottom: 28px;
    border: 1px solid rgba(211, 173, 116, 0.55);
    border-left: 4px solid var(--theme-gold);
    background: var(--theme-dark);
    padding: 22px 24px;
    color: var(--theme-white);
}

.theme-review-status--success {
    border-left-color: var(--color-success-foreground, #b7d8ba);
}

.theme-review-status h2,
.theme-review-report-card h2 {
    margin: 0 0 10px;
    color: var(--theme-gold-soft);
    font-size: 22px;
}

.theme-review-status p,
.theme-review-report-card p {
    margin: 0;
}

.theme-review-report-card__rating {
    color: var(--theme-gold);
    font-weight: 700;
}

.theme-review-opt-out {
    display: flex;
    justify-content: center;
}

.theme-reviews {
    width: min(calc(100% - 32px), 1120px);
    margin: 48px auto 0;
    padding: 40px;
    border-top: 1px solid rgba(211, 173, 116, 0.45);
}

.theme-reviews__header {
    padding-bottom: 32px;
    border-bottom: 1px solid rgba(211, 173, 116, 0.35);
}

.theme-reviews__header > h2 {
    margin: 0;
    color: var(--theme-gold);
    font-size: clamp(28px, 4vw, 42px);
    font-weight: 300;
}

.theme-reviews__summary {
    display: grid;
    grid-template-columns: 190px minmax(0, 1fr);
    gap: 44px;
    align-items: center;
    max-width: 760px;
    margin-top: 28px;
}

.theme-reviews__average-value {
    margin: 0;
    color: var(--theme-white);
    font-family: var(--font-serif);
    font-size: 52px;
    line-height: 1;
}

.theme-reviews__average-value span {
    font-size: 24px;
}

.theme-reviews__average > p:last-child {
    margin: 10px 0 0;
    color: rgba(255, 255, 255, 0.68);
    font-size: 13px;
}

.theme-reviews__stars {
    display: inline-flex;
    align-items: center;
    gap: 3px;
    margin-top: 14px;
    color: var(--theme-gold);
}

.theme-reviews__stars svg {
    width: 23px;
    height: 23px;
}

.theme-reviews__stars--small {
    margin-top: 0;
}

.theme-reviews__stars--small svg {
    width: 19px;
    height: 19px;
}

.theme-reviews__stars strong {
    margin-left: 8px;
    color: var(--theme-white);
    font-family: var(--font-sans);
    font-size: 14px;
}

.theme-reviews__distribution {
    display: grid;
    gap: 8px;
}

.theme-reviews__distribution-row {
    display: grid;
    grid-template-columns: 48px minmax(0, 1fr) 34px;
    gap: 12px;
    align-items: center;
}

.theme-reviews__distribution-label {
    display: inline-flex;
    align-items: center;
    gap: 5px;
    font-family: var(--font-sans);
    font-size: 13px;
}

.theme-reviews__distribution-label svg {
    width: 14px;
    height: 14px;
    color: var(--theme-gold);
}

.theme-reviews__distribution-track {
    display: block;
    height: 7px;
    overflow: hidden;
    background: rgba(255, 255, 255, 0.16);
}

.theme-reviews__distribution-track > span {
    display: block;
    height: 100%;
    background: var(--theme-gold);
}

.theme-reviews__distribution-count {
    color: rgba(255, 255, 255, 0.68);
    font-family: var(--font-sans);
    font-size: 13px;
    text-align: right;
}

.theme-reviews__policy {
    max-width: 800px;
    margin: 26px 0 0;
    color: rgba(255, 255, 255, 0.7);
    font-size: 13px;
}

.theme-reviews__empty {
    padding: 34px 0;
    color: rgba(255, 255, 255, 0.72);
}

.theme-reviews__list {
    display: grid;
}

.theme-review {
    display: grid;
    grid-template-columns: 220px minmax(0, 1fr);
    gap: 36px;
    padding: 34px 0;
    border-bottom: 1px solid rgba(211, 173, 116, 0.25);
}

.theme-review__identity {
    padding-right: 28px;
    border-right: 1px solid rgba(211, 173, 116, 0.25);
}

.theme-review__author {
    display: flex;
    align-items: center;
    gap: 12px;
}

.theme-review__avatar {
    display: grid;
    width: 42px;
    height: 42px;
    flex: 0 0 42px;
    place-items: center;
    background: var(--theme-dark);
    color: var(--theme-gold);
}

.theme-review__avatar svg,
.theme-review__verified svg {
    width: 22px;
    height: 22px;
}

.theme-review__dates,
.theme-review__verified,
.theme-review__report {
    color: rgba(255, 255, 255, 0.65);
    font-size: 13px;
}

.theme-review__dates {
    margin: 18px 0 0;
}

.theme-review__verified {
    display: inline-flex;
    align-items: center;
    gap: 8px;
    margin: 14px 0 0;
    color: var(--theme-gold-soft);
}

.theme-review__content h3 {
    margin: 18px 0 0;
    color: var(--theme-white);
    font-size: 22px;
}

.theme-review__comment {
    margin: 16px 0 0;
    color: rgba(255, 255, 255, 0.84);
}

.theme-review__reply {
    margin-top: 22px;
    padding: 18px;
    border-left: 3px solid var(--theme-gold);
    background: var(--theme-dark);
}

.theme-review__reply p {
    margin: 8px 0 0;
}

.theme-review__report {
    margin: 20px 0 0;
}

.theme-reviews__pagination {
    display: flex;
    flex-wrap: wrap;
    align-items: center;
    justify-content: center;
    gap: 16px;
    margin-top: 30px;
}

.theme-review-modal {
    position: fixed;
    inset: 0;
    z-index: 160;
    display: flex;
    align-items: center;
    justify-content: center;
    padding: 20px;
}

.theme-review-modal__backdrop {
    position: absolute;
    inset: 0;
    border: 0;
    background: rgba(0, 0, 0, 0.78);
}

.theme-review-modal__dialog {
    position: relative;
    z-index: 1;
    display: flex;
    width: min(1120px, 100%);
    max-height: 92vh;
    flex-direction: column;
    overflow: hidden;
    border: 1px solid var(--theme-gold);
    background: var(--theme-black);
    box-shadow: 0 32px 90px rgba(0, 0, 0, 0.62);
}

.theme-review-modal__header {
    display: flex;
    align-items: flex-start;
    justify-content: space-between;
    gap: 20px;
    padding: 20px 28px;
    border-bottom: 1px solid rgba(211, 173, 116, 0.45);
    background: var(--theme-dark);
}

.theme-review-modal__header h2,
.theme-review-modal__header p {
    margin: 0;
}

.theme-review-modal__header h2 {
    color: var(--theme-gold);
    font-size: 26px;
}

.theme-review-modal__header p {
    margin-top: 5px;
    color: rgba(255, 255, 255, 0.7);
    font-size: 13px;
}

.theme-review-modal__close {
    display: grid;
    width: 40px;
    height: 40px;
    flex: 0 0 40px;
    place-items: center;
    border: 1px solid rgba(211, 173, 116, 0.65);
    background: transparent;
    color: var(--theme-white);
    font-size: 32px;
    line-height: 1;
}

.theme-review-modal__content {
    overflow-y: auto;
}

.theme-review-modal .theme-reviews {
    width: 100%;
    margin: 0;
    border-top: 0;
}

.theme-review-policy__sections {
    display: grid;
    gap: 34px;
}

.theme-review-policy__sections section {
    padding-left: 22px;
    border-left: 3px solid rgba(211, 173, 116, 0.7);
}

.theme-review-policy__sections h2 {
    margin: 0;
    color: var(--theme-gold);
    font-size: 24px;
}

.theme-review-policy__sections p,
.theme-review-policy__sections ul {
    margin: 12px 0 0;
    color: rgba(255, 255, 255, 0.78);
}

.theme-review-policy__sections ul {
    padding-left: 22px;
}

@media (max-width: 720px) {
    .theme-review-page {
        padding: 48px 0 72px;
    }

    .theme-review-form .theme-auth-form,
    .theme-review-page > .theme-container > .theme-auth-form,
    .theme-reviews {
        padding: 22px 18px;
    }

    .theme-reviews__summary,
    .theme-review {
        grid-template-columns: 1fr;
        gap: 24px;
    }

    .theme-review__identity {
        padding-right: 0;
        padding-bottom: 22px;
        border-right: 0;
        border-bottom: 1px solid rgba(211, 173, 116, 0.25);
    }

    .theme-review-modal {
        padding: 8px;
    }

    .theme-review-modal__header {
        padding: 16px 18px;
    }
}

* {
    box-sizing: border-box;
}

html {
    scroll-behavior: smooth;
}

body {
    margin: 0;
    background: var(--theme-black);
    color: var(--theme-white);
    font-family: var(--font-serif);
    font-weight: 100;
}

main {
    position: relative;
    width: 100%;
    overflow: hidden;
    background-color: var(--theme-black);
}

a {
    color: inherit;
    text-decoration: none;
}

button,
[role="button"],
input[type="button"],
input[type="submit"],
input[type="reset"] {
    cursor: pointer;
}

button:disabled,
button[aria-disabled="true"],
[role="button"][aria-disabled="true"],
input[type="button"]:disabled,
input[type="submit"]:disabled,
input[type="reset"]:disabled {
    cursor: not-allowed;
}

img,
svg {
    display: block;
}

img {
    max-width: 100%;
}

p,
li {
    font-family: var(--font-sans);
    line-height: 1.65;
}

p,
span,
li,
h3,
h4,
h5 {
    color: inherit;
}

h1,
h2,
h3,
h4,
h5,
h6 {
    font-family: var(--font-serif);
    font-weight: 100;
    letter-spacing: 0;
}

[x-cloak] {
    display: none !important;
}

html .turbo-progress-bar {
    height: 3px;
    background-color: var(--theme-gold);
}

.hidden {
    display: none !important;
}

.sr-only {
    position: absolute;
    width: 1px;
    height: 1px;
    padding: 0;
    overflow: hidden;
    clip: rect(0, 0, 0, 0);
    white-space: nowrap;
    border: 0;
}

.theme-container {
    width: min(calc(100% - 32px), var(--theme-container));
    margin-right: auto;
    margin-left: auto;
}

.theme-page {
    padding: 72px 0;
    color: var(--theme-white);
}

.theme-intro {
    max-width: 900px;
    margin: 0 auto;
    text-align: center;
    font-size: 18px;
}

.theme-intro .theme-italic {
    font-style: italic;
}

.theme-intro .theme-quote-author {
    display: block;
    margin-top: 8px;
    font-size: 16px;
    text-align: right;
}

.theme-bold {
    font-weight: 700;
    font-size: 18px;
}

.theme-button-fill,
.theme-button-stroke {
    display: inline-flex;
    align-items: center;
    justify-content: center;
    min-height: 42px;
    border: 1px solid var(--theme-gold);
    padding: 10px 18px;
    font-family: var(--font-serif);
    font-size: 14px;
    font-weight: 700;
    line-height: 1.2;
    text-align: center;
    transition: color 160ms ease, background-color 160ms ease, border-color 160ms ease;
}

.theme-button-fill {
    background: var(--theme-gold);
    color: var(--theme-black);
}

.theme-button-stroke {
    background: transparent;
    color: var(--theme-white);
}

.theme-button-fill:hover,
.theme-button-stroke:hover {
    border-color: var(--theme-white);
    background: var(--theme-white);
    color: var(--theme-black);
}

.theme-button-fill.theme-is-disabled,
.theme-button-fill:disabled,
.theme-button-stroke:disabled {
    opacity: 0.55;
    cursor: not-allowed;
    pointer-events: none;
}

a.disabled {
    opacity: 0.7;
    cursor: default;
    pointer-events: none;
}

.theme-hover-link-effect,
.theme-hover-link-effect-2,
.theme-hover-link-effect-3 {
    transition: color 160ms ease, border-color 160ms ease, background-color 160ms ease, opacity 160ms ease;
}

.theme-hover-link-effect:hover,
.theme-hover-link-effect-2:hover,
.theme-hover-link-effect-3:hover {
    color: var(--theme-gold);
}

.theme-picture {
    display: block;
    overflow: hidden;
}

.theme-picture img {
    width: 100%;
    height: 100%;
    object-fit: cover;
}

.theme-picture--landscape {
    height: 400px;
}

/* Header and menu */
.theme-header-nav-simple {
    position: relative;
    height: 100vh;
    min-height: 600px;
    margin-top: 0;
    margin-bottom: 25px;
}

.theme-navbar-nav-simple {
    position: relative;
    z-index: 40;
}

[data-announcement-banner] {
    z-index: 30;
}

.theme-navbar-nav-simple .theme-menu-logo {
    display: flex;
    justify-content: center;
    padding: 0 16px;
    pointer-events: none;
}

.theme-navbar-nav-simple .theme-menu-logo a {
    pointer-events: auto;
}

.theme-navbar-nav-simple .theme-menu-logo img {
    width: auto;
    max-width: 180px;
    height: 200px;
    margin: 0 auto 20px;
}

.theme-product-header {
    border-bottom: 1px solid rgba(211, 173, 116, 0.18);
    background: #141414;
}

.theme-product-header .theme-navbar-nav-simple .theme-menu-logo {
    display: flex;
    min-height: clamp(8rem, 14vw, 12rem);
    align-items: center;
    padding: clamp(1rem, 2vw, 2rem) 4rem;
}

.theme-product-header .theme-navbar-nav-simple .theme-menu-logo img {
    width: auto;
    max-width: clamp(8rem, 15vw, 11rem);
    height: clamp(6rem, 11vw, 9rem);
    margin: 0 auto;
}

.theme-navbar-nav-simple nav {
    position: fixed;
    top: 20px;
    right: 0;
    z-index: 70;
    width: 50px;
    min-height: 0;
    background: var(--theme-gold);
    color: var(--theme-white);
    text-align: center;
}

.theme-menu-picto {
    position: relative;
    display: flex;
    width: 50px;
    height: 50px;
    align-items: center;
    justify-content: center;
    padding: 10px 0;
    text-align: center;
    background: var(--theme-dark);
}

.theme-menu-picto a {
    position: absolute;
    inset: 0;
    z-index: 2;
}

.theme-menu-picto img {
    width: 50%;
    max-width: 50px;
    height: auto;
    margin: 0 auto;
}

.theme-menu-labels {
    display: flex;
    min-height: 0;
    flex-direction: column;
    align-items: center;
    gap: 10px;
    margin: 12px auto;
}

.theme-menu-labels .theme-nav-open {
    display: grid;
    width: 100%;
    height: 34px;
    padding: 0;
    cursor: pointer;
    place-items: center;
    border: 0;
    background: transparent;
    color: var(--theme-white);
    appearance: none;
}

.theme-nav-open__lines {
    position: relative;
    display: block;
    width: 20px;
    height: 18px;
    margin: 0 auto;
}

.theme-nav-open__lines i {
    display: block;
    width: 20px;
    height: 2px;
    margin: 0 auto;
    background: currentColor;
    transition: transform 200ms ease, opacity 200ms ease;
}

.theme-nav-open__lines i + i {
    margin-top: 4px;
}

.theme-nav-open__lines.theme-is-open i:first-child {
    transform: translateY(6px) rotate(135deg);
}

.theme-nav-open__lines.theme-is-open i:nth-child(2) {
    opacity: 0;
}

.theme-nav-open__lines.theme-is-open i:nth-child(3) {
    transform: translateY(-6px) rotate(45deg);
}

.theme-nav-actions {
    display: flex;
    flex-direction: column;
    align-items: center;
    gap: 10px;
}

.theme-language-switcher {
    display: flex;
    width: 34px;
    min-height: 24px;
    align-items: center;
    justify-content: center;
    gap: 2px;
    color: rgba(255, 255, 255, 0.72);
    font-family: var(--font-sans);
    font-size: 9px;
    font-weight: 700;
    letter-spacing: 0.02em;
    line-height: 1;
}

.theme-language-switcher a {
    color: var(--theme-white);
    text-decoration: none;
}

.theme-language-switcher a:hover,
.theme-language-switcher a:focus-visible {
    color: var(--theme-gold);
    outline: none;
}

.theme-language-switcher [aria-current="page"] {
    color: var(--theme-gold);
}

.theme-nav-icon-button {
    position: relative;
    display: grid;
    width: 34px;
    height: 34px;
    cursor: pointer;
    place-items: center;
    border: 1px solid rgba(255, 255, 255, 0.65);
    border-radius: 50%;
    background: rgba(28, 28, 28, 0.14);
    color: var(--theme-white);
    transition: background-color 160ms ease, border-color 160ms ease, color 160ms ease;
    appearance: none;
}

.theme-nav-icon-button:hover,
.theme-nav-icon-button:focus-visible {
    border-color: var(--theme-white);
    background: var(--theme-dark);
    color: var(--theme-white);
    outline: none;
}

.theme-nav-icon-button__icon {
    width: 18px;
    height: 18px;
}

.theme-nav-cart__count {
    position: absolute;
    top: -7px;
    right: -7px;
    display: grid;
    min-width: 17px;
    height: 17px;
    place-items: center;
    border-radius: 999px;
    background: var(--theme-dark);
    color: var(--theme-white);
    font-family: "Roboto", sans-serif;
    font-size: 10px;
    font-weight: 700;
    line-height: 1;
}

.theme-nav-container {
    position: fixed;
    top: 0;
    left: 0;
    z-index: 60;
    width: 100%;
    height: 100vh;
    overflow-y: auto;
    background: var(--theme-gray);
    padding: 50px;
    opacity: 0;
    pointer-events: none;
    visibility: hidden;
    transform: translateX(100%);
    transition: all 500ms ease;
}

.theme-nav-container.theme-is-open {
    opacity: 1;
    pointer-events: auto;
    visibility: visible;
    transform: translateX(0);
}

.theme-nav-container.theme-is-closed {
    opacity: 0;
    visibility: hidden;
    transform: translateX(100%);
}

.theme-nav-container > .theme-container {
    position: absolute;
    top: 50%;
    right: 0;
    left: 0;
    transform: translateY(-50%);
}

.theme-menu-grid {
    display: grid;
    grid-template-columns: repeat(auto-fit, minmax(400px, 1fr));
    gap: 20px;
    grid-auto-flow: dense;
    align-items: center;
    height: 100% !important;
}

.theme-menu-block,
.theme-menu-img-bg {
    position: relative;
    width: 100%;
    height: 300px;
    overflow: hidden;
    border-left: 4px solid var(--theme-gold);
    background: var(--theme-white);
    color: var(--theme-dark);
}

.theme-menu-block {
    list-style: none;
}

.theme-menu-block > a,
.theme-menu-img-bg > a {
    position: absolute;
    inset: 0;
    z-index: 5;
}

.theme-menu-block p,
.theme-menu-img-bg p {
    position: absolute;
    right: 0;
    bottom: 0;
    left: 0;
    z-index: 2;
    margin: 0;
    padding: 10px;
    font-family: "Josefin Sans", sans-serif;
    font-size: 16px;
    font-weight: 300;
    line-height: 1.1;
    text-align: left;
}

.theme-menu-block p.theme-vertical-center {
    top: 50%;
    bottom: auto;
    transform: translateY(-50%);
}

.theme-menu-block p span,
.theme-menu-img-bg p span {
    display: block;
    margin-bottom: 20px;
    padding-top: 10px;
    color: var(--theme-gold);
    font-family: var(--font-serif);
    font-size: 1.4em;
    font-weight: 500;
    text-transform: uppercase;
}

.theme-menu-img-bg {
    color: var(--theme-white);
}

.theme-menu-img-bg picture,
.theme-menu-img-bg img {
    position: absolute;
    inset: 0;
    display: inline-block;
    width: 100%;
    height: 100%;
    overflow: hidden;
}

.theme-menu-img-bg img {
    object-fit: cover;
    transition: transform 500ms ease;
}

.theme-menu-img-bg::after {
    position: absolute;
    inset: 0;
    content: "";
    background: linear-gradient(0deg, rgba(28, 28, 28, 0.4) 0%, rgba(255, 255, 255, 0) 63%);
}

.theme-menu-img-bg p span {
    color: var(--theme-white);
}

.theme-menu-block--contact {
    padding-bottom: 30px;
}

.theme-social-links {
    position: absolute;
    right: 34px;
    bottom: 30px;
    left: 34px;
    z-index: 10;
    display: flex;
    justify-content: center;
    align-items: end;
    gap: 20px;
    height: auto;
    margin: 0;
    padding: 0;
    list-style: none;
}

.theme-social-link {
    display: grid;
    width: 40px;
    height: 40px;
    place-items: center;
    border: 1px solid currentColor;
    border-radius: 999px;
}

.theme-social-link svg {
    width: 18px;
    height: 18px;
    fill: currentColor;
}

.theme-social-links--dark {
    color: var(--theme-dark);
}

.theme-social-links--light {
    color: var(--theme-white);
}

.theme-social-link:hover {
    color: var(--theme-gold);
}

/* Hero */
.theme-hero {
    position: relative;
    z-index: 1;
    display: block;
    width: 100%;
    height: 70vh;
    min-height: 400px;
    overflow: visible;
    background-repeat: no-repeat;
    background-position: 50% 70%;
    background-size: cover;
    text-align: center;
}

.theme-hero::before {
    position: absolute;
    inset: 0;
    z-index: 1;
    content: "";
    background: radial-gradient(circle, rgba(28, 28, 28, 0.4) 0%, rgba(255, 255, 255, 0) 55%);
}

.theme-hero::after {
    position: absolute;
    inset: 0;
    z-index: 1;
    content: "";
    background: rgba(0, 0, 0, 0.2);
}

.theme-hero .theme-background-image {
    position: absolute;
    inset: 0;
    z-index: 0;
    display: block;
    overflow: hidden;
}

.theme-hero .theme-background-image picture,
.theme-hero .theme-background-image img {
    width: 100%;
    height: 100%;
}

.theme-hero .theme-background-image img {
    object-fit: cover;
    object-position: 50% 70%;
}

.theme-hero .theme-hero-titles {
    position: absolute;
    top: 50%;
    right: 0;
    left: 0;
    z-index: 2;
    width: min(calc(100% - 30px), 1170px);
    margin: auto;
    text-align: center;
    transform: translateY(-50%);
}

.theme-hero h2 {
    margin: 0;
    color: var(--theme-gold);
    font-family: "Josefin Sans", sans-serif;
    font-size: 40px;
    font-weight: 100;
    line-height: 56px;
}

.theme-hero h2 span {
    display: block;
    margin-top: 0;
    color: var(--theme-white);
    font-size: 40px;
    font-weight: 300;
    text-transform: uppercase;
}

.theme-hero h1 {
    display: block;
    margin: 0;
    padding: 0;
    background: transparent;
    color: var(--theme-gold);
    font-size: 10em;
    font-weight: 500;
    line-height: 1.4;
    opacity: 0.15;
    text-transform: uppercase;
}

.theme-scroll-indicator {
    position: absolute;
    right: 0;
    bottom: 55px;
    left: 0;
    z-index: 5;
    color: var(--theme-white);
    font-size: 16px;
    line-height: 24px;
    text-align: center;
}

.theme-scroll-indicator a {
    color: var(--theme-white);
    font-family: "Josefin Sans", sans-serif;
    font-weight: 300;
    text-transform: uppercase;
}

.theme-scroll-indicator a:first-child {
    font-family: "Josefin Sans", sans-serif;
    font-weight: 300;
    text-transform: uppercase;
}

.theme-scroll-indicator svg {
    position: absolute;
    right: 0;
    bottom: -100px;
    left: 0;
    width: auto;
    height: 80px;
    margin: 0 auto;
    animation: bounce 2s infinite;
    fill: var(--theme-gold);
}

.theme-scroll-indicator .theme-scroll-arrow__path {
    fill: var(--theme-gold);
}

/* Homepage */
.theme-homepage-page {
    padding: 0;
    margin-bottom: 50px;
}

.theme-homepage-grid,
.theme-home-grid {
    display: grid;
    grid-template-columns: 470px 670px;
    align-items: center;
    justify-content: center;
    gap: 0 30px;
}

.theme-homepage-content-5 {
    grid-column: span 1;
    text-align: center;
}

.theme-homepage-content-5 img {
    width: 180px;
    margin: 0 auto 28px;
}

.theme-homepage-content-5 h3,
.theme-homepage-contact-content h3,
.theme-history-title,
.theme-shop-heading {
    position: relative;
    margin: 0 0 20px;
    color: var(--theme-white);
    font-size: 31px;
    font-weight: 400;
    line-height: 43.4px;
    text-transform: uppercase;
}

.theme-homepage-content-5 h3::after,
.theme-homepage-contact-content h3::after,
.theme-shop-heading::after {
    position: absolute;
    right: 0;
    bottom: -15px;
    left: 0;
    display: block;
    width: 250px;
    height: 3px;
    margin: 0 auto;
    content: "";
    background: var(--theme-gold);
}

.theme-homepage-contact-content h3 {
    position: static;
    margin: 0 0 8px;
    font-size: 31px;
    font-weight: 100;
    line-height: 43.4px;
}

.theme-homepage-contact-content h3::after {
    content: none;
    display: inline;
    position: static;
    width: auto;
    height: auto;
    background: transparent;
}

.theme-homepage-content-5 p {
    margin: 0 auto 20px;
    max-width: 430px;
}

.theme-homepage-content-5 p span {
    color: var(--theme-gold);
    font-weight: 400;
}

.theme-discover-link,
.theme-homepage-shop-image {
    position: relative;
    grid-column: span 1;
}

.theme-discover-link > a {
    position: absolute;
    top: 50%;
    right: 0;
    display: block;
    z-index: 2;
    padding-left: 10px;
    background: var(--theme-gold);
    color: var(--theme-white);
    font-family: "Josefin Sans", sans-serif;
    font-size: 0.8em;
    font-weight: 400;
    line-height: 1.5;
    transform: translateY(-50%);
    transition: right 600ms ease, background-color 600ms ease;
}

.theme-discover-link > a:hover {
    right: 10px;
    background: var(--theme-gold);
    color: var(--theme-white);
}

.theme-discover-link > a i {
    position: relative;
    display: inline-flex;
    width: 28px;
    height: 32.8px;
    align-items: center;
    justify-content: center;
    margin-left: 10px;
    vertical-align: middle;
    background: var(--theme-black);
    color: var(--theme-white);
}

.theme-discover-link > a i::before {
    display: block;
    width: 8px;
    height: 8px;
    content: "";
    border-top: 2px solid currentColor;
    border-right: 2px solid currentColor;
    transform: rotate(45deg);
}

.theme-homepage-cuvee-content {
    position: relative;
    grid-column: 1 / -1;
    min-height: 560px;
    margin: 55px 0 15px;
}

.theme-homepage-cuvee-row {
    display: grid;
    grid-template-columns: 470px 670px;
    gap: 0 30px;
    align-items: center;
}

.theme-homepage-cuvee-img {
    position: relative;
    z-index: 3;
    text-align: right;
}

.theme-homepage-cuvee-bottle {
    display: block;
    width: 140px;
    max-width: 100%;
    height: 500px;
    margin-left: auto;
}

.theme-homepage-cuvee-bottle > div {
    width: 100%;
    height: 100%;
}

.theme-homepage-cuvee-bottle__row {
    display: block;
}

.theme-homepage-cuvee-bottle__image {
    width: 100%;
    height: 100%;
    object-fit: contain;
}

.theme-homepage-cuvee-img img {
    max-height: 500px;
    margin-left: auto;
}

.theme-homepage-cuvee-text {
    position: relative;
    z-index: 2;
    padding-left: 48px;
    text-align: left;
}

.theme-homepage-cuvee-text p {
    max-width: 420px;
}

.theme-homepage-cuvee-title-back {
    position: absolute;
    right: 0;
    bottom: 260px;
    left: 0;
    display: grid;
    grid-template-columns: 470px 670px;
    gap: 0 30px;
    align-items: center;
    pointer-events: none;
}

.theme-homepage-cuvee-title-back h3 {
    position: relative;
    z-index: 0;
    width: 80%;
    margin: 0 0 8px;
    background: var(--theme-gold);
    padding: 0 10px;
    color: var(--theme-white);
    font-size: 31px;
    font-weight: 400;
    line-height: 43.4px;
    text-align: left;
    text-transform: uppercase;
}

.theme-homepage-cuvee-title-back h3::before {
    position: absolute;
    top: 50%;
    right: 0;
    left: 0;
    z-index: -1;
    content: "";
    background: var(--theme-gold);
    padding: 40px;
    transform: translateY(-50%);
}

.theme-homepage-cuvee-title-back span {
    display: block;
    max-width: 520px;
    color: rgba(211, 173, 116, 0.2);
    font-family: var(--font-serif);
    font-size: clamp(44px, 7vw, 78px);
    font-weight: 700;
    line-height: 0.95;
    text-transform: uppercase;
}

.theme-homepage-shop-text {
    grid-column: span 1;
}

.theme-homepage-shop-image,
.theme-homepage-shop-text {
    grid-row: 3;
    margin-top: 55px;
}

.theme-homepage-shop-image {
    grid-column: 1 / -1;
    width: 670px;
    justify-self: start;
}

.theme-homepage-shop-text {
    grid-column: 1 / -1;
    width: 470px;
    justify-self: end;
    align-self: center;
}

.theme-homepage-contact-content {
    grid-row: 4;
    margin-top: 55px;
}

.theme-homepage-contact-content {
    grid-column: 1 / -1;
    text-align: center;
}

.theme-homepage-contact-content p {
    max-width: 780px;
    margin: 0 auto 24px;
}

.theme-homepage-contact-content a + a {
    margin-left: 12px;
}

/* House */
.theme-home-page.theme-page {
    padding: 0;
}

.theme-home-page .theme-intro {
    max-width: 1140px;
    font-size: 20.8px;
    line-height: 33.28px;
}

.theme-home-grid {
    display: grid;
    grid-template-columns: 1fr;
    gap: 0;
}

.theme-home-row {
    display: grid;
    grid-template-columns: repeat(12, minmax(0, 1fr));
    align-items: center;
}

.theme-home-cell {
    min-width: 0;
    margin: 15px;
    padding: 15px;
}

.theme-home-cell--5 {
    grid-column: span 5;
}

.theme-home-cell--7 {
    grid-column: span 7;
}

.theme-home-cell--full {
    grid-column: 1 / -1;
}

.theme-home-cell--left {
    grid-column: 1 / span 7;
}

.theme-home-cell--right {
    grid-column: 8 / span 5;
}

.theme-home-picture {
    display: block;
    width: 100%;
    overflow: hidden;
}

.theme-home-picture img {
    width: 100%;
    height: 100%;
    object-fit: cover;
}

.theme-home-picture--top img {
    object-position: 50% 0;
}

.theme-home-picture--panel {
    height: 400px;
}

.theme-home-picture--wide {
    height: 500px;
}

.theme-home-intro,
.theme-split-text,
.theme-old-pictures {
    grid-column: 1 / -1;
}

.theme-home-title-panel {
    grid-column: span 5;
}

.theme-home-image-panel {
    grid-column: span 7;
}

.theme-home-title-panel--right {
    grid-column: 8 / span 5;
    grid-row: auto;
}

.theme-home-image-panel--left {
    grid-column: 1 / span 7;
    grid-row: auto;
}

.theme-history-title {
    background: var(--theme-dark);
    width: 120%;
    margin: 0;
    padding: 50px 10px;
    font-size: 31px;
    font-weight: 400;
    line-height: 43.4px;
}

.theme-history-title.theme-title-right {
    transform: translateX(-60px);
    width: 114%;
    padding-left: 20px;
}

.theme-split-text {
    column-count: 2;
    column-gap: 50px;
    column-rule: 1px solid var(--theme-gray);
    font-family: var(--font-sans);
    font-weight: 400;
    line-height: 24px;
    text-align: justify;
}

.theme-old-pictures {
    display: grid;
    grid-template-columns: repeat(7, minmax(0, 1fr));
    gap: 20px;
}

.theme-old-pictures img {
    width: 100%;
    height: 100%;
    object-fit: cover;
}

.theme-old-pictures .theme-landscape {
    grid-column: span 2 / span 2;
}

.theme-old-pictures .theme-portrait {
    grid-column: span 1 / span 1;
}

/* Cuvees */
.theme-cuvees-intro,
.theme-cuvees-order {
    text-align: center;
}

.theme-cuvees-order {
    margin-top: 44px;
}

.theme-variant-collection {
    margin-top: 44px;
}

.theme-variant-collection > h2 {
    margin: 0 0 44px;
    color: var(--theme-gold);
    font-size: clamp(28px, 4vw, 42px);
    text-align: center;
    text-transform: uppercase;
}

.theme-cuvee-grid {
    display: grid;
    grid-template-columns: repeat(auto-fit, minmax(min(100%, 280px), 1fr));
    gap: 54px 30px;
    text-align: center;
}

.theme-cuvee-item {
    min-width: 0;
}

.theme-cuvee-item-img {
    position: relative;
    z-index: 1;
}

.theme-cuvee-item-img a {
    position: relative;
    display: inline-block;
}

.theme-cuvee-item-picture,
.theme-cuvee-item-picture > picture,
.theme-cuvee-item-picture__image {
    position: relative;
    z-index: 2;
}

.theme-cuvee-item-picture__image {
    width: auto;
    max-height: 500px;
    object-fit: contain;
}

.theme-cuvee-item-square {
    position: absolute;
    top: 70%;
    left: -30px;
    z-index: -1;
    width: 30px;
    height: 70px;
    transform: translateY(0);
    transition: transform 600ms ease;
}

.theme-cuvee-item-img a:hover .theme-cuvee-item-square {
    transform: translateY(10%);
}

.theme-cuvee-item-info {
    padding: 18px 10px 0;
}

.theme-cuvee-item-info h3 {
    margin: 0;
    color: var(--theme-white);
    font-size: 24px;
    text-transform: uppercase;
}

.theme-cuvee-item-info h4 {
    margin: 8px 0 14px;
    color: var(--theme-gold);
    font-family: var(--font-sans);
    font-size: 15px;
    font-weight: 700;
    text-transform: uppercase;
}

.theme-cuvee-item-info p {
    min-height: 28px;
    margin: 0 0 16px;
}

.theme-cuvee-detail {
    color: var(--theme-white);
}

.theme-cuvee-detail__content {
    display: grid;
    grid-template-columns: minmax(0, 5fr) minmax(280px, 6fr);
    gap: 48px;
    align-items: center;
}

.theme-cuvee-detail__body {
    min-width: 0;
}

.theme-cuvee-detail h2 {
    margin: 0;
    color: var(--theme-white);
    font-size: clamp(32px, 5vw, 64px);
    line-height: 1;
    text-transform: uppercase;
}

.theme-cuvee-detail__quality {
    display: block;
    margin-top: 6px;
    color: var(--theme-gold);
    font-family: var(--font-sans);
    font-size: 18px;
    font-weight: 700;
    text-transform: uppercase;
}

.theme-cuvee-detail__description {
    margin-top: 26px;
}

.theme-cuvee-detail__description p {
    margin: 0 0 12px;
}

.theme-cuvee-detail__technical {
    display: grid;
    gap: 10px;
    margin-top: 24px;
}

.theme-cuvee-detail__technical-row {
    display: grid;
    grid-template-columns: 130px minmax(0, 1fr);
    gap: 14px;
    font-family: var(--font-sans);
    line-height: 1.55;
}

.theme-cuvee-detail__technical-row > span {
    color: var(--theme-gold);
    font-weight: 700;
}

.theme-cuvee-detail__technical-row p {
    margin: 0;
}

.theme-cuvee-detail__awards {
    display: flex;
    flex-wrap: wrap;
    gap: 12px;
    margin-top: 24px;
}

.theme-cuvee-detail__award-image {
    width: 58px;
    height: 58px;
    object-fit: contain;
}

.theme-cuvee-detail__actions {
    display: flex;
    flex-wrap: wrap;
    gap: 12px;
    margin-top: 28px;
}

.theme-cuvee-detail__media {
    position: relative;
    display: flex;
    min-height: 520px;
    align-items: center;
    justify-content: center;
}

.theme-cuvee-detail__picture,
.theme-cuvee-detail__picture > picture,
.theme-cuvee-detail__image {
    position: relative;
    z-index: 2;
}

.theme-cuvee-detail__image {
    width: auto;
    max-height: 620px;
    object-fit: contain;
}

.theme-cuvee-detail__square {
    position: absolute;
    top: 58%;
    left: -42px;
    z-index: 1;
    width: 42px;
    height: 120px;
    transform: translateY(-50%);
}

.theme-custom-stickers-page {
    padding-top: 0;
}

.theme-stickers-title {
    margin-bottom: 16px;
    color: var(--theme-white);
    font-family: var(--font-sans);
    font-size: 24px;
    font-weight: 400;
}

.theme-stickers-link {
    color: var(--theme-gold);
}

.theme-stickers {
    display: flex;
    flex-wrap: wrap;
    justify-content: center;
    gap: 30px;
    margin-top: 30px;
}

.theme-stickers > div {
    flex: 0 1 220px;
    width: min(100%, 220px);
}

.theme-stickers img {
    width: 100%;
}

/* Contact */
.theme-contact-page.theme-page {
    margin-bottom: 50px;
    padding: 0;
}

.theme-contact-content {
    max-width: none;
    margin: 0 auto;
    padding: 30px 15px 0;
    text-align: center;
}

.theme-contact-page .theme-intro {
    max-width: 1140px;
    font-size: 20.8px;
    line-height: 33.28px;
}

.theme-contact-content > p:not(.theme-intro) {
    max-width: 760px;
    margin: 70px auto 0;
    font-family: var(--font-sans);
    font-size: 16px;
    line-height: 28px;
}

.theme-contact-form {
    position: relative;
    width: min(100%, 740px);
    margin: 60px auto 0;
    text-align: left;
}

.theme-contact-honeypot {
    position: absolute;
    left: -100vw;
    width: 1px;
    height: 1px;
    overflow: hidden;
}

.theme-contact-form .theme-form-group {
    margin-bottom: 16px;
}

.theme-contact-form input:not([type="hidden"]),
.theme-contact-form textarea {
    display: block;
    width: 100%;
    border: 0;
    background: var(--theme-dark);
    padding: 8px;
    color: var(--theme-white);
    font-family: var(--font-serif);
    font-size: 16px;
    font-weight: 400;
    line-height: 24px;
    outline: none;
}

.theme-contact-form input:not([type="hidden"]) {
    height: 39px;
    min-height: 39px;
}

.theme-contact-form textarea {
    height: 208px;
    min-height: 208px;
    resize: vertical;
}

.theme-contact-form input::placeholder,
.theme-contact-form textarea::placeholder {
    color: rgba(255, 255, 255, 0.28);
}

.theme-contact-form .form-error,
.theme-contact-form .invalid-feedback,
.theme-contact-form .form-errors {
    margin-top: 6px;
    color: var(--theme-gold-soft);
    font-family: var(--font-sans);
    font-size: 13px;
}

.theme-contact-captcha {
    width: 260px;
    margin-bottom: 16px;
    color: var(--theme-white);
}

.theme-contact-captcha altcha-widget {
    width: 260px;
    min-height: 70px;
    color-scheme: dark;
    --altcha-color-base: var(--theme-dark);
    --altcha-color-border: rgba(211, 173, 116, 0.65);
    --altcha-color-text: var(--theme-white);
    --altcha-color-border-focus: var(--theme-gold);
}

.theme-contact-submit {
    text-align: right;
}

.theme-button-border {
    display: inline-flex;
    min-height: 38px;
    align-items: center;
    justify-content: center;
    border: 1px solid var(--theme-gold);
    background: transparent;
    padding: 9px 20px;
    color: var(--theme-gold);
    font-family: var(--font-serif);
    font-size: 14px;
    font-weight: 700;
    text-transform: uppercase;
    cursor: pointer;
}

.theme-button-border:hover {
    background: var(--theme-white);
    color: var(--theme-black);
}

.theme-contact-actions {
    display: flex;
    flex-wrap: wrap;
    justify-content: center;
    gap: 16px;
    margin-top: 30px;
}

/* Legal pages */
.theme-legal {
    background: var(--theme-black);
    color: var(--theme-white);
}

.theme-legal .bg-page,
.theme-legal .bg-surface {
    background: transparent;
}

.theme-legal article > section {
    border: 0;
    background: transparent;
    box-shadow: none;
}

.theme-legal h1,
.theme-legal h2 {
    color: var(--theme-white);
}

.theme-legal h2 {
    font-size: 31px;
    line-height: 43.4px;
    text-transform: none;
}

.theme-legal p,
.theme-legal li {
    color: var(--theme-white);
    font-family: var(--font-sans);
    font-size: 16px;
    font-weight: 400;
    line-height: 24px;
}

.theme-legal a {
    color: var(--theme-gold);
}

.theme-legal-page {
    background: var(--theme-black);
}

.theme-legal-content {
    padding: 5px 15px 78px;
}

.theme-legal-block {
    margin-bottom: 30px;
}

.theme-legal-block h2 {
    margin: 0 0 14px;
    color: var(--theme-white);
    font-size: 31px;
    font-weight: 400;
    line-height: 43.4px;
    text-transform: none;
}

.theme-legal-block p,
.theme-legal-block li {
    margin: 0;
    color: var(--theme-white);
    font-family: var(--font-sans);
    font-size: 16px;
    font-weight: 400;
    line-height: 24px;
}

.theme-legal-block > p + p {
    margin-top: 1rem;
}

.theme-legal-block li {
    display: list-item;
    list-style: disc outside;
}

.theme-legal-block ul {
    margin: 0;
    padding-left: 18px;
}

.theme-legal-link {
    margin: 18px 0 0;
    color: var(--theme-gold);
    font-family: var(--font-serif);
    font-size: 25px;
    font-weight: 400;
    line-height: 35px;
}

.theme-legal-link a {
    color: inherit;
}

/* Account and authentication */
.theme-auth-page,
.theme-account {
    background: var(--theme-black);
    color: var(--theme-white);
}

.app_login .theme-header-nav-simple,
.app_register_confirm .theme-header-nav-simple,
.app_register_pending .theme-header-nav-simple,
.app_forgot_password .theme-header-nav-simple,
.app_forgot_password_pending .theme-header-nav-simple,
.app_reset_password .theme-header-nav-simple,
.app_account .theme-header-nav-simple {
    height: auto;
    min-height: 0;
    margin-bottom: 0;
}

.theme-auth-frame {
    display: block;
}

.theme-eyebrow {
    margin: 0 0 10px;
    color: var(--theme-gold);
    font-family: "Josefin Sans", sans-serif;
    font-size: 13px;
    font-weight: 400;
    line-height: 1.4;
    text-transform: uppercase;
}

.theme-richtext {
    display: grid;
    gap: 14px;
    margin-top: 22px;
}

.theme-richtext p {
    margin: 0;
    color: var(--theme-white);
}

.theme-richtext strong {
    color: var(--theme-gold);
    font-weight: 700;
}

.theme-auth-grid {
    display: grid;
    grid-template-columns: repeat(2, minmax(0, 1fr));
    gap: 28px;
    align-items: stretch;
    width: min(100%, 1040px);
    margin: 0 auto;
}

.theme-auth-card,
.theme-account-panel {
    border: 1px solid rgba(211, 173, 116, 0.45);
    border-left: 5px solid var(--theme-gold);
    background: linear-gradient(145deg, rgba(60, 60, 59, 0.94), rgba(20, 20, 20, 0.98));
    color: var(--theme-white);
}

.theme-auth-card {
    display: flex;
    min-width: 0;
    flex-direction: column;
    padding: 28px;
}

.theme-auth-card--single {
    width: min(100%, 640px);
    margin: 0 auto;
}

.theme-auth-card--muted {
    background: linear-gradient(145deg, rgba(48, 48, 47, 0.94), rgba(20, 20, 20, 0.98));
}

.theme-auth-card__heading h2,
.theme-account__header h2,
.theme-account-panel__heading h3,
.theme-account-form__section h4 {
    margin: 0;
    color: var(--theme-white);
    font-family: var(--font-serif);
    font-weight: 400;
    line-height: 1.2;
}

.theme-auth-card__heading h2 {
    font-size: 30px;
    text-transform: uppercase;
}

.theme-auth-card__heading p:not(.theme-eyebrow),
.theme-account__header p,
.theme-account-panel__heading p,
.theme-account-form__section > p {
    margin: 12px 0 0;
    color: rgba(255, 255, 255, 0.82);
    font-family: var(--font-sans);
    font-size: 15px;
    line-height: 1.7;
}

.theme-auth-form {
    display: grid;
    gap: 18px;
    margin-top: 26px;
}

.theme-form-field,
.theme-account-form .flex.min-w-0.flex-col {
    display: grid;
    min-width: 0;
    gap: 8px;
}

.theme-auth-form label:not(.theme-checkbox),
.theme-account-form label:not(.theme-checkbox) {
    color: var(--theme-gold);
    font-family: "Josefin Sans", sans-serif;
    font-size: 12px;
    font-weight: 400;
    line-height: 1.3;
    text-transform: uppercase;
}

.theme-auth-form input:not([type="hidden"]):not([type="checkbox"]),
.theme-auth-form select,
.theme-auth-form textarea,
.theme-account-form input:not([type="hidden"]):not([type="checkbox"]),
.theme-account-form select,
.theme-account-form textarea {
    width: 100%;
    min-width: 0;
    min-height: 44px;
    border: 1px solid rgba(211, 173, 116, 0.72);
    border-radius: 0;
    background: var(--theme-dark);
    padding: 10px 12px;
    color: var(--theme-white);
    font-family: var(--font-sans);
    font-size: 15px;
    outline: none;
    box-shadow: none;
}

.theme-auth-form textarea,
.theme-account-form textarea {
    min-height: 120px;
    resize: vertical;
}

.theme-auth-form input:not([type="hidden"]):not([type="checkbox"]):focus,
.theme-auth-form select:focus,
.theme-auth-form textarea:focus,
.theme-account-form input:not([type="hidden"]):not([type="checkbox"]):focus,
.theme-account-form select:focus,
.theme-account-form textarea:focus {
    border-color: var(--theme-white);
}

.theme-form-input--disabled,
.theme-auth-form input:disabled,
.theme-account-form input:disabled {
    opacity: 0.68;
}

.theme-form-line {
    display: flex;
    flex-wrap: wrap;
    align-items: center;
    justify-content: space-between;
    gap: 12px;
}

.theme-checkbox {
    display: inline-flex;
    max-width: 100%;
    align-items: flex-start;
    gap: 10px;
    color: rgba(255, 255, 255, 0.82);
    font-family: var(--font-sans);
    font-size: 14px;
    line-height: 1.55;
}

.theme-checkbox--panel {
    border: 1px solid rgba(211, 173, 116, 0.28);
    background: rgba(20, 20, 20, 0.32);
    padding: 12px;
}

.theme-checkbox__input {
    width: 16px;
    height: 16px;
    flex: 0 0 16px;
    margin-top: 3px;
    accent-color: var(--theme-gold);
}

.theme-inline-link {
    color: var(--theme-gold);
    font-family: var(--font-sans);
    text-decoration: underline;
    text-underline-offset: 4px;
}

.theme-inline-link:hover,
.theme-inline-link:focus {
    color: var(--theme-white);
}

.theme-form-button {
    display: inline-flex;
    min-height: 46px;
    cursor: pointer;
    align-items: center;
    justify-content: center;
    border: 1px solid var(--theme-gold);
    padding: 10px 18px;
    font-family: var(--font-serif);
    font-size: 14px;
    font-weight: 700;
    line-height: 1.2;
    text-align: center;
    text-transform: uppercase;
    transition: color 160ms ease, background-color 160ms ease, border-color 160ms ease, opacity 160ms ease;
}

.theme-form-button--fill {
    background: var(--theme-gold);
    color: var(--theme-black);
}

.theme-form-button--stroke {
    background: transparent;
    color: var(--theme-white);
}

.theme-form-button:hover,
.theme-form-button:focus {
    border-color: var(--theme-white);
    background: var(--theme-white);
    color: var(--theme-black);
}

.theme-form-button:disabled {
    opacity: 0.5;
    cursor: not-allowed;
}

.theme-form-note {
    margin: 0;
    color: rgba(255, 255, 255, 0.7);
    font-size: 13px;
}

.theme-form-error,
.theme-form-error ul,
.theme-auth-form .text-error-foreground,
.theme-account-form .text-error-foreground {
    margin: 0;
    color: #ffd0ca;
    font-family: var(--font-sans);
    font-size: 13px;
    list-style: none;
    padding: 0;
}

.theme-form-actions {
    display: flex;
    flex-wrap: wrap;
    gap: 12px;
    margin-top: 28px;
}

.theme-auth-form altcha-widget,
.theme-account-form altcha-widget {
    color-scheme: dark;
    --altcha-color-base: var(--theme-dark);
    --altcha-color-border: rgba(211, 173, 116, 0.72);
    --altcha-color-text: var(--theme-white);
}

.theme-payment-form {
    width: 100%;
}

.theme-payment-form .theme-auth-card {
    margin: 0 auto;
}

.theme-payment-form h1 {
    margin: 0;
    color: var(--theme-white);
    font-family: var(--font-serif);
    font-size: 30px;
    font-weight: 400;
    line-height: 1.2;
    text-transform: uppercase;
}

.theme-payment-method {
    color: var(--theme-gold) !important;
}

.theme-payment-alert {
    width: min(100%, 760px);
    margin: 0 auto;
    border: 1px solid #ff9a8d;
    background: rgba(112, 24, 24, 0.35);
    padding: 18px 20px;
    color: #ffd0ca;
    font-family: var(--font-sans);
}

.theme-account__header {
    display: flex;
    align-items: flex-end;
    justify-content: space-between;
    gap: 24px;
    margin-bottom: 36px;
    border-bottom: 1px solid rgba(211, 173, 116, 0.45);
    padding: 0 0 24px;
}

.theme-account__header > div {
    max-width: 720px;
}

.theme-account__header h2 {
    font-size: 36px;
    text-transform: uppercase;
}

.theme-account__grid {
    display: grid;
    grid-template-columns: minmax(0, 0.9fr) minmax(0, 1.1fr);
    gap: 28px;
    align-items: start;
}

.theme-account-panel {
    min-width: 0;
    padding: 26px;
}

.theme-account-panel__heading {
    margin-bottom: 22px;
}

.theme-account-panel__heading h3 {
    font-size: 26px;
}

.theme-account-empty,
.theme-account-group {
    border: 1px dashed rgba(211, 173, 116, 0.55);
    background: rgba(20, 20, 20, 0.28);
    padding: 18px;
    color: rgba(255, 255, 255, 0.82);
}

.theme-account-group {
    display: grid;
    gap: 8px;
    margin-bottom: 20px;
}

.theme-order-list,
.theme-account-form {
    display: grid;
    gap: 18px;
}

.theme-order-card {
    display: grid;
    gap: 18px;
    border: 1px solid rgba(211, 173, 116, 0.28);
    background: rgba(20, 20, 20, 0.32);
    padding: 18px;
}

.theme-order-card__top {
    display: flex;
    align-items: flex-start;
    justify-content: space-between;
    gap: 14px;
}

.theme-order-card__label,
.theme-order-card__details dt {
    color: var(--theme-gold);
    font-family: "Josefin Sans", sans-serif;
    font-size: 11px;
    line-height: 1.3;
    text-transform: uppercase;
}

.theme-order-card__number {
    margin-top: 6px;
    color: var(--theme-white);
    font-family: var(--font-serif);
    font-size: 24px;
    font-weight: 400;
}

.theme-status {
    display: inline-flex;
    flex-shrink: 0;
    align-items: center;
    border: 1px solid rgba(211, 173, 116, 0.55);
    background: rgba(211, 173, 116, 0.12);
    padding: 5px 8px;
    color: var(--theme-gold-soft);
    font-family: "Josefin Sans", sans-serif;
    font-size: 11px;
    text-transform: uppercase;
}

.theme-status--paid {
    border-color: rgba(166, 205, 143, 0.7);
    color: #d9f3c8;
}

.theme-status--failed,
.theme-status--canceled {
    border-color: rgba(238, 123, 116, 0.7);
    color: #ffd0ca;
}

.theme-order-card__details {
    display: grid;
    grid-template-columns: repeat(2, minmax(0, 1fr));
    gap: 14px;
    margin: 0;
}

.theme-order-card__details dd {
    margin: 4px 0 0;
    color: rgba(255, 255, 255, 0.82);
    font-family: var(--font-sans);
    font-size: 14px;
}

.theme-account-form__section {
    display: grid;
    gap: 16px;
    border: 1px solid rgba(211, 173, 116, 0.28);
    background: rgba(20, 20, 20, 0.32);
    padding: 18px;
}

.theme-account-form__section h4 {
    font-size: 22px;
}

.theme-account-form__grid {
    display: grid;
    grid-template-columns: repeat(2, minmax(0, 1fr));
    gap: 16px;
}

.theme-account-form__grid--three {
    grid-template-columns: repeat(3, minmax(0, 1fr));
}

.theme-account-form__grid--invoice {
    margin-top: 2px;
}

.theme-account-form__wide {
    grid-column: 1 / -1;
}

.theme-account-form__nested {
    border: 1px solid rgba(211, 173, 116, 0.2);
    padding: 16px;
}

.theme-account-form__section-head {
    display: flex;
    align-items: flex-start;
    justify-content: space-between;
    gap: 16px;
}

.theme-account-form__actions {
    display: flex;
    justify-content: flex-end;
}

@media (max-width: 1024px) {
    .theme-auth-grid,
    .theme-account__grid {
        grid-template-columns: 1fr;
    }
}

@media (max-width: 720px) {
    .theme-auth-card,
    .theme-account-panel {
        padding: 20px;
    }

    .theme-auth-card__heading h2,
    .theme-account__header h2 {
        font-size: 26px;
    }

    .theme-account__header,
    .theme-order-card__top,
    .theme-account-form__section-head {
        align-items: stretch;
        flex-direction: column;
    }

    .theme-order-card__details,
    .theme-account-form__grid,
    .theme-account-form__grid--three {
        grid-template-columns: 1fr;
    }

    .theme-form-line {
        align-items: flex-start;
        flex-direction: column;
    }
}

/* Shop */
.theme-shop-layout {
    display: flex;
    flex-direction: column;
    gap: 48px;
}

.theme-shop-vacation {
    width: min(100%, 960px);
    margin-inline: auto;
    border: 1px solid rgba(211, 173, 116, 0.65);
    background: rgba(211, 173, 116, 0.1);
    padding: 24px clamp(20px, 5vw, 56px);
    color: var(--theme-white);
    font-family: var(--font-serif);
    line-height: 1.7;
    text-align: center;
}

.theme-shop-vacation > * + * {
    margin-top: 12px;
}

.theme-shop-vacation a {
    color: var(--theme-gold-soft);
    text-decoration: underline;
    text-underline-offset: 3px;
}

.theme-shop-partner {
    max-width: 760px;
    margin: 0 auto 24px;
}

.theme-shop-partner__panel {
    border: 1px solid rgba(211, 173, 116, 0.55);
    background: var(--theme-dark);
    padding: 24px;
    color: var(--theme-white);
}

.theme-shop-partner__panel--active {
    position: relative;
    display: grid;
    grid-template-columns: auto minmax(0, 1fr) auto;
    align-items: center;
    gap: 20px;
    overflow: hidden;
    background:
        linear-gradient(115deg, rgba(211, 173, 116, 0.13), transparent 48%),
        var(--theme-dark);
}

.theme-shop-partner__panel--active::before {
    position: absolute;
    inset: 0 auto 0 0;
    width: 4px;
    content: "";
    background: var(--theme-gold);
}

.theme-shop-partner__status {
    display: grid;
    width: 44px;
    height: 44px;
    place-items: center;
    border: 1px solid rgba(211, 173, 116, 0.72);
    color: var(--theme-gold-soft);
}

.theme-shop-partner__status svg {
    width: 24px;
    height: 24px;
    fill: none;
    stroke: currentcolor;
    stroke-linecap: square;
    stroke-linejoin: miter;
    stroke-width: 1.8;
}

.theme-shop-partner__content {
    min-width: 0;
}

.theme-shop-partner__title {
    margin-bottom: 10px;
    color: var(--theme-gold);
    font-family: var(--font-serif);
    font-weight: 700;
    text-transform: uppercase;
}

.theme-shop-partner__panel--active .theme-shop-partner__title {
    margin-bottom: 5px;
    font-size: 12px;
    letter-spacing: 0.1em;
}

.theme-shop-partner__text {
    color: rgba(255, 255, 255, 0.82);
    font-family: var(--font-sans);
    font-size: 15px;
    line-height: 1.55;
}

.theme-shop-partner__reset {
    display: inline-flex;
    min-height: 40px;
    align-items: center;
    justify-content: center;
    gap: 8px;
    border: 1px solid rgba(211, 173, 116, 0.55);
    background: transparent;
    padding: 9px 14px;
    color: var(--theme-gold-soft);
    font-family: var(--font-serif);
    font-size: 12px;
    font-weight: 700;
    text-transform: uppercase;
    transition: color 160ms ease, background-color 160ms ease, border-color 160ms ease;
}

.theme-shop-partner__reset svg {
    width: 16px;
    height: 16px;
    fill: none;
    stroke: currentcolor;
    stroke-linecap: square;
    stroke-linejoin: miter;
    stroke-width: 1.7;
}

.theme-shop-partner__reset:hover,
.theme-shop-partner__reset:focus-visible {
    border-color: var(--theme-white);
    background: var(--theme-white);
    color: var(--theme-black);
}

.theme-shop-partner__form {
    display: flex;
    gap: 12px;
}

.theme-shop-partner__error {
    margin-top: 12px;
    color: var(--theme-gold-soft);
}

.theme-shop-input,
.theme-shop-select,
.theme-shop-mobile-select {
    width: 100%;
    min-width: 0;
    border: 1px solid var(--theme-gold);
    background: var(--theme-dark);
    padding: 10px 12px;
    color: var(--theme-white);
    outline: none;
}

.theme-shop-input::placeholder {
    color: rgba(255, 255, 255, 0.62);
}

.theme-shop-blocked {
    position: relative;
    display: grid;
    width: min(100%, 960px);
    grid-template-columns: auto minmax(0, 1fr);
    gap: clamp(20px, 4vw, 36px);
    overflow: hidden;
    margin: 0 auto;
    border: 1px solid rgba(211, 173, 116, 0.58);
    background:
        radial-gradient(circle at 100% 0, rgba(211, 173, 116, 0.17), transparent 34%),
        var(--theme-dark);
    padding: clamp(28px, 5vw, 52px);
    color: var(--theme-white);
}

.theme-shop-blocked::before {
    position: absolute;
    inset: 0 auto 0 0;
    width: 4px;
    content: "";
    background: var(--theme-gold);
}

.theme-shop-blocked__icon {
    display: grid;
    width: 58px;
    height: 58px;
    place-items: center;
    border: 1px solid rgba(211, 173, 116, 0.72);
    color: var(--theme-gold-soft);
}

.theme-shop-blocked__icon svg {
    width: 31px;
    height: 31px;
    fill: none;
    stroke: currentcolor;
    stroke-linecap: square;
    stroke-linejoin: miter;
    stroke-width: 1.25;
}

.theme-shop-blocked__content {
    min-width: 0;
}

.theme-shop-blocked__eyebrow {
    margin: 0 0 9px;
    color: var(--theme-gold);
    font-family: var(--font-serif);
    font-size: 12px;
    font-weight: 700;
    letter-spacing: 0.12em;
    text-transform: uppercase;
}

.theme-shop-blocked h2 {
    max-width: 760px;
    margin: 0;
    color: var(--theme-white);
    font-size: clamp(24px, 3.4vw, 34px);
    font-weight: 400;
    line-height: 1.28;
}

.theme-shop-blocked__description {
    margin-top: 22px;
    border-top: 1px solid rgba(211, 173, 116, 0.24);
    border-bottom: 1px solid rgba(211, 173, 116, 0.24);
    padding: 16px 0;
    color: rgba(255, 255, 255, 0.78);
    font-family: var(--font-sans);
    font-size: 15px;
    line-height: 1.7;
}

.theme-shop-blocked__description > * {
    margin: 0 0 10px;
}

.theme-shop-blocked__description > :last-child {
    margin-bottom: 0;
}

.theme-shop-blocked__contact {
    display: flex;
    align-items: center;
    justify-content: space-between;
    gap: 24px;
    margin-top: 24px;
}

.theme-shop-blocked__contact p {
    max-width: 520px;
    margin: 0;
    color: rgba(255, 255, 255, 0.72);
    font-size: 14px;
}

.theme-shop-blocked__contact .theme-button-fill {
    flex: 0 0 auto;
}

.theme-shop-heading {
    margin-top: 24px;
    text-align: center;
}

.theme-shop-tabs {
    width: min(100%, 960px);
    margin: 0 auto;
}

.theme-shop-tabs .shop-tabs-splide {
    font-family: var(--font-serif);
}

.theme-shop-tabs .shop-tab-link {
    display: block;
    border: 1px solid var(--theme-gold);
    padding: 10px 18px;
    color: var(--theme-gold-soft);
    font-size: 13px;
    letter-spacing: 0.08em;
    text-transform: uppercase;
    transition:
        background-color 180ms ease,
        color 180ms ease;
}

.theme-shop-tabs .shop-tab-link:hover,
.theme-shop-tabs .shop-tab-link:focus-visible,
.theme-shop-tabs .shop-tab-link.is-active,
.theme-shop-tabs .shop-tab-link[data-shop-tabs-active="true"] {
    background: var(--theme-gold);
    color: var(--theme-dark);
}

.theme-shop-tabs .splide__pagination__page {
    background: rgba(255, 255, 255, 0.35);
}

.theme-shop-tabs .splide__pagination__page.is-active {
    background: var(--theme-gold);
}

.theme-shop-collection-description {
    max-width: 760px;
    margin: 18px auto 52px;
    text-align: center;
}

.theme-shop-product-grid {
    display: grid;
    grid-template-columns: repeat(3, minmax(0, 1fr));
    margin-top: 52px;
    gap: 64px 42px;
}

.theme-shop-collection-description + .theme-shop-product-grid {
    margin-top: 0;
}

.theme-shop-product-panel,
.theme-shop-product-card-live,
.theme-shop-product-form {
    height: 100%;
}

.theme-shop-product-card {
    display: flex;
    height: 100%;
    flex-direction: column;
    align-items: stretch;
    color: var(--theme-white);
    font-family: var(--font-serif);
    text-align: center;
}

.theme-shop-product-card__media {
    position: relative;
    min-height: 350px;
    margin-bottom: 12px;
}

.theme-shop-product-card__media--gallery {
    margin-bottom: 42px;
}

.theme-shop-product-card__media .product-gallery,
.theme-shop-product-card__media .splide__track,
.theme-shop-product-card__media .splide__list,
.theme-shop-product-card__media .splide__slide,
.theme-shop-product-card__image,
.theme-shop-product-card__image-row {
    height: 350px;
}

.theme-shop-product-card__image-element {
    width: 100%;
    height: 350px;
    object-fit: contain;
}

.theme-shop-product-card__media .product-gallery .splide__pagination {
    bottom: -1.5rem;
}

.theme-shop-product-card__commerce-line {
    display: flex;
    min-height: 32px;
    align-items: center;
    justify-content: center;
    flex-wrap: wrap;
    gap: 8px;
    margin-bottom: 10px;
    line-height: 1.2;
}

.theme-shop-product-card__ribbon,
.theme-shop-product-card__state {
    display: inline-flex;
    min-height: 22px;
    align-items: center;
    padding: 3px 10px;
    color: var(--theme-white);
    font-family: var(--font-serif);
    font-size: 12px;
    font-weight: 400;
    text-transform: uppercase;
}

.theme-shop-product-card__state {
    background: var(--theme-gold);
    color: var(--theme-black);
}

.theme-shop-product-card__awards {
    position: absolute;
    bottom: 0;
    left: 0;
    z-index: 3;
    display: grid;
    gap: 6px;
}

.theme-shop-product-card__awards button {
    width: 54px;
    border: 0;
    background: transparent;
    padding: 0;
    cursor: pointer;
}

.theme-shop-product-card__award {
    width: 54px;
}

.theme-shop-product-card__body {
    display: flex;
    flex: 1;
    flex-direction: column;
    padding: 0 0 2px;
}

.theme-shop-product-card__header {
    margin: 5px auto 10px;
}

.theme-shop-product-card__cuvee-header {
    display: block;
    margin-bottom: 3px;
    color: var(--theme-white);
    font-size: 13px;
}

.theme-shop-product-card__title {
    margin: 0;
    font-family: var(--font-serif);
    font-size: 18px;
    font-weight: 400;
    line-height: 1.25;
    text-transform: none;
}

.theme-shop-product-card__quality {
    margin-top: 4px;
    color: var(--theme-white);
    font-size: 13px;
    font-weight: 400;
    line-height: 1.35;
}

.theme-shop-product-card__price {
    display: inline-flex;
    min-height: 32px;
    align-items: baseline;
    gap: 6px;
    background: var(--theme-dark);
    padding: 5px 14px;
    color: var(--theme-white);
    font-size: 18px;
    font-weight: 400;
    white-space: nowrap;
}

.theme-shop-product-card__price sup {
    position: static;
    font-size: 10px;
    line-height: 1;
}

.theme-shop-product-card__price-old {
    opacity: 0.72;
    text-decoration: line-through;
}

.theme-shop-product-card__degressive {
    border: 0;
    background: transparent;
    padding: 6px 0 0;
    color: var(--theme-gold);
    cursor: pointer;
    font-size: 12px;
    text-decoration: underline;
    text-underline-offset: 4px;
}

.theme-shop-product-card__controls {
    margin-top: auto;
    padding-top: 8px;
}

.theme-shop-product-card__fields {
    display: grid;
    grid-template-columns: 1fr;
    gap: 8px;
    align-items: center;
}

.theme-shop-product-card__field {
    min-width: 0;
}

.theme-shop-product-card__single-choice {
    min-height: 34px;
    padding: 8px 10px;
    color: var(--theme-white);
    font-size: 18px;
    font-weight: 700;
    line-height: 1.25;
    text-align: center;
}

.theme-shop-product-card .theme-shop-select {
    min-height: 34px;
    border-color: var(--theme-gold);
    background-color: var(--theme-dark);
    padding: 8px 10px;
    color: var(--theme-white);
    font-family: var(--font-serif);
    font-size: 13px;
}

.theme-shop-quantity {
    display: grid;
    grid-template-columns: minmax(0, 1fr) 44px;
    align-items: center;
    gap: 8px;
}

.theme-shop-quantity__label {
    color: var(--theme-white);
    font-size: 13px;
    line-height: 1.2;
    text-align: left;
}

.theme-shop-quantity__input {
    width: 44px;
    min-width: 44px;
    height: 34px;
    border: 1px solid var(--theme-gold);
    background-color: var(--theme-dark);
    padding: 4px;
    color: var(--theme-white);
    font-family: var(--font-serif);
    font-size: 13px;
    text-align: center;
}

.theme-shop-quantity__stepper {
    display: none;
    align-items: center;
    border: 1px solid var(--theme-gold);
    background: var(--theme-dark);
}

.theme-shop-quantity__stepper button,
.theme-shop-quantity__stepper span {
    display: grid;
    width: 34px;
    height: 34px;
    place-items: center;
    border: 0;
    background: transparent;
    color: var(--theme-white);
    font-size: 13px;
}

.theme-shop-quantity__stepper button {
    cursor: pointer;
    font-size: 16px;
}

.theme-shop-product-card__actions {
    display: grid;
    grid-template-columns: minmax(0, 7fr) minmax(0, 5fr);
    gap: 12px;
    margin-top: 10px;
}

.theme-shop-product-card__actions > :only-child {
    grid-column: 1 / -1;
}

.theme-shop-product-card__detail,
.theme-shop-product-card__submit {
    width: 100%;
    min-height: 34px;
    padding: 9px 12px;
    font-size: 13px;
    font-weight: 400;
    line-height: 1.2;
    text-decoration: none;
    text-transform: none;
}

.theme-shop-product-card__submit {
    margin-top: 0;
}

.theme-shop-product-card__unavailable {
    border: 1px solid rgba(211, 173, 116, 0.55);
    padding: 8px;
    font-size: 12px;
    text-align: center;
}

.theme-shop-empty {
    display: grid;
    justify-items: center;
    gap: 18px;
    text-align: center;
}

.theme-shop-product-detail__header {
    display: grid;
    justify-items: center;
    gap: 24px;
    text-align: center;
}

.theme-shop-product-detail__category {
    color: var(--theme-gold);
    font-family: var(--font-serif);
    font-size: 15px;
    text-transform: uppercase;
}

.theme-shop-product-detail__quality {
    color: var(--theme-white);
    font-family: var(--font-serif);
    font-size: 18px;
}

.theme-shop-product-detail__body {
    display: grid;
    width: min(100%, 620px);
    gap: 48px;
    margin: 0 auto;
}

.theme-shop-product-detail__body .theme-shop-product-card {
    max-width: 540px;
    margin: 0 auto;
}

.theme-shop-information-section {
    width: 100%;
}

.theme-shop-information-grid {
    display: grid;
    gap: 18px;
}

.theme-shop-information-carousel--mobile {
    display: block;
}

.theme-shop-information-carousel--desktop,
.theme-shop-information-grid--desktop-only {
    display: none;
}

.theme-shop-information-grid--1 {
    max-width: 420px;
    margin: 0 auto;
}

.theme-shop-information-grid--2 {
    grid-template-columns: repeat(2, minmax(0, 1fr));
}

.theme-shop-information-grid--3 {
    grid-template-columns: repeat(3, minmax(0, 1fr));
}

.theme-shop-information-card {
    display: flex;
    height: 100%;
    flex-direction: column;
    border: 1px solid rgba(211, 173, 116, 0.5);
    border-left: 5px solid var(--theme-gold);
    background: var(--theme-dark);
    padding: 18px;
    color: var(--theme-white);
}

.theme-shop-information-card__header {
    display: flex;
    align-items: flex-start;
    gap: 14px;
    border-bottom: 1px solid rgba(211, 173, 116, 0.22);
    padding-bottom: 12px;
}

.theme-shop-information-card__image {
    display: grid;
    width: 46px;
    height: 46px;
    flex-shrink: 0;
    place-items: center;
    border: 1px solid rgba(211, 173, 116, 0.5);
    padding: 6px;
}

.theme-shop-information-card h3 {
    margin: 0;
    color: var(--theme-gold);
    font-size: 18px;
}

.theme-shop-information-card__header span {
    display: block;
    width: 44px;
    height: 2px;
    margin-top: 8px;
    background: var(--theme-gold);
}

.theme-shop-information-card__description {
    flex: 1;
    margin: 14px 0 16px;
    font-size: 14px;
}

.theme-shop-information-card__description p {
    margin: 0;
}

@media (min-width: 768px) {
    .theme-shop-information-carousel--mobile {
        display: none;
    }

    .theme-shop-information-carousel--desktop {
        display: block;
    }

    .theme-shop-information-grid--desktop-only {
        display: grid;
    }
}

.theme-shop-legal-notice {
    margin-top: 12px;
}

.theme-shop-legal-notice__inner {
    display: flex;
    align-items: center;
    gap: 24px;
    border: 1px solid rgba(211, 173, 116, 0.35);
    background: var(--theme-white);
    padding: 18px 24px;
    color: var(--theme-black);
}

.theme-shop-legal-notice__image {
    flex: 0 0 100px;
    width: 100px;
    max-width: 100px;
}

.theme-shop-legal-notice__image > * {
    display: block;
    width: 100%;
    max-width: 100%;
}

.theme-shop-legal-notice__image picture {
    display: block;
    width: 100% !important;
    max-width: 100% !important;
}

.theme-shop-legal-notice__image img {
    display: block;
    width: 100%;
    height: auto;
    aspect-ratio: 1;
    object-fit: contain;
}

.theme-shop-legal-notice__content {
    flex: 1 1 auto;
    min-width: 0;
}

.theme-shop-legal-notice p {
    margin: 0 0 8px;
    color: var(--theme-black);
    font-size: 13px;
}

.theme-shop-mobile-bar {
    position: fixed;
    right: 0;
    bottom: 0;
    left: 0;
    z-index: 50;
    border-top: 1px solid rgba(211, 173, 116, 0.35);
    background: rgba(20, 20, 20, 0.96);
    padding: 12px 12px max(12px, env(safe-area-inset-bottom));
}

/* Modals */
.modal-scroll-lock [role="dialog"] {
    --color-surface: #1d1c1b;
    --color-page: var(--theme-black);
    --color-foreground: var(--theme-white);

    color-scheme: dark;
    border-color: rgba(211, 173, 116, 0.58);
    background:
        linear-gradient(145deg, rgba(60, 60, 59, 0.94), rgba(20, 20, 20, 0.98) 58%),
        var(--theme-black);
    color: var(--theme-white);
    box-shadow: 0 32px 90px rgba(0, 0, 0, 0.62);
}

.modal-scroll-lock [role="dialog"] > div:first-child {
    border-bottom-color: rgba(211, 173, 116, 0.55);
}

.modal-scroll-lock [role="dialog"] h1,
.modal-scroll-lock [role="dialog"] h2,
.modal-scroll-lock [role="dialog"] h3,
.modal-scroll-lock [role="dialog"] h4,
.modal-scroll-lock [role="dialog"] [id$="-title"] {
    color: var(--theme-white);
}

.modal-scroll-lock [role="dialog"] p,
.modal-scroll-lock [role="dialog"] li {
    color: inherit;
}

.modal-scroll-lock [role="dialog"] a:not(.bg-accent) {
    color: var(--theme-gold-soft);
}

.modal-scroll-lock [role="dialog"] .bg-accent,
.modal-scroll-lock [role="dialog"] .theme-button-fill {
    color: var(--theme-black);
}

.modal-scroll-lock [role="dialog"] .bg-surface\/50,
.modal-scroll-lock [role="dialog"] .bg-surface\/70 {
    background: rgba(255, 255, 255, 0.06);
}

.modal-scroll-lock [role="dialog"] :is(input, select, textarea) {
    border: 1px solid rgba(211, 173, 116, 0.45);
    background: var(--theme-dark);
    color: var(--theme-white);
}

.modal-scroll-lock [role="dialog"] :is(input, select, textarea):focus {
    border-color: var(--theme-gold);
    outline: 2px solid rgba(211, 173, 116, 0.25);
    outline-offset: 2px;
}

.modal-scroll-lock [role="dialog"] option {
    background: var(--theme-dark);
    color: var(--theme-white);
}

.modal-scroll-lock [role="dialog"] table {
    background: rgba(20, 20, 20, 0.72);
}

.modal-scroll-lock [role="dialog"] ::selection {
    background: var(--theme-gold);
    color: var(--theme-black);
}

/* Fiche produit VitiCore 2 */

.theme-product-page,
.modal-scroll-lock,
[data-theme-product-toast] {
    --color-primary: #ffffff;
    --color-primary-container: #3c3c3b;
    --color-secondary: #d3ad74;
    --color-background: #141414;
    --color-surface: #1d1c1b;
    --color-surface-container: #252524;
    --color-surface-container-low: #1a1a19;
    --color-surface-container-high: #30302f;
    --color-surface-container-highest: #3c3c3b;
    --color-surface-variant: #30302f;
    --color-on-surface-variant: #f4f0ea;
    --color-outline: #d3ad74;
    --color-primary-fixed: #d3ad74;
    --color-primary-fixed-dim: #b88f55;
    --color-secondary-fixed: #f4d49d;
    --font-family-display: "Libre Bodoni", serif;
    --font-family-body: "Libre Franklin", sans-serif;
    color: var(--color-primary);
    color-scheme: dark;
    font-family: "Libre Franklin", sans-serif;
    font-weight: 400;
    -webkit-font-smoothing: antialiased;
}

.theme-product-page .font-body,
.theme-product-page .font-label,
.modal-scroll-lock .font-body,
.modal-scroll-lock .font-label {
    font-family: "Libre Franklin", sans-serif;
}

.theme-product-page .font-display,
.modal-scroll-lock .font-display {
    font-family: "Libre Bodoni", serif;
}

.theme-product-page .font-medium,
.modal-scroll-lock .font-medium {
    font-weight: 500;
}

.theme-product-page .font-semibold,
.modal-scroll-lock .font-semibold {
    font-weight: 600;
}

.theme-product-page .theme-product-gallery-thumbnails {
    display: none;
}

@media (min-width: 64rem) {
    .theme-product-page .theme-product-gallery-thumbnails {
        display: block;
        grid-column: 1;
        order: 1;
    }

    .theme-product-page .theme-product-gallery-main-wrap {
        grid-column: 2;
        min-width: 0;
        order: 2;
    }
}

@media (min-width: 80rem) {
    .theme-product-page .theme-product-detail-grid {
        gap: 3.5rem;
        padding: 3rem;
    }
}

.theme-product-page .material-symbols-outlined,
.modal-scroll-lock .material-symbols-outlined {
    display: inline-block;
    font-family: "Material Symbols Outlined", sans-serif;
    font-style: normal;
    font-variation-settings: "FILL" 0, "wght" 300, "GRAD" 0, "opsz" 24;
    font-weight: normal;
    line-height: 1;
    vertical-align: middle;
}

.theme-product-page .shop-product-gallery-thumb[aria-current="true"] {
    opacity: 1;
}

.theme-product-page button.shop-product-gallery-thumb {
    flex: none;
    height: 5rem;
    width: 5rem;
}

.theme-product-page :where(button, input[type="button"], input[type="submit"], input[type="reset"], [role="button"]):not(:disabled):not([aria-disabled="true"]),
.modal-scroll-lock :where(button, [role="button"]):not(:disabled):not([aria-disabled="true"]) {
    cursor: pointer;
}

/* Cart */
.theme-cart-drawer {
    position: fixed;
    top: 0;
    right: 0;
    z-index: 90;
    display: flex;
    width: min(100vw, 430px);
    height: 100vh;
    max-height: 100svh;
    flex-direction: column;
    gap: 10px;
    overflow: hidden;
    background: var(--theme-black);
    padding: 14px;
    color: var(--theme-white);
    box-shadow: -24px 0 60px rgba(0, 0, 0, 0.34);
}

.theme-cart-drawer__header {
    display: flex;
    align-items: center;
    justify-content: space-between;
    border-bottom: 2px solid var(--theme-gold);
    padding-bottom: 8px;
}

.theme-cart-drawer__header h2 {
    margin: 0;
    font-size: 18px;
}

.theme-cart-drawer__header button {
    display: grid;
    width: 34px;
    height: 34px;
    cursor: pointer;
    place-items: center;
    border: 0;
    background: transparent;
    color: var(--theme-white);
}

.theme-cart-drawer__header svg {
    width: 18px;
    fill: currentColor;
}

.theme-cart-drawer__body,
.theme-cart-form,
.theme-cart-form__filled,
.theme-cart-form__form {
    min-height: 0;
    flex: 1;
}

.theme-cart-drawer__body,
.theme-cart-form {
    display: flex;
    flex-direction: column;
    overflow: hidden;
}

.theme-cart-form__filled,
.theme-cart-form__form {
    display: flex;
    flex-direction: column;
    overflow: hidden;
}

.theme-cart-form__items {
    min-height: 0;
    flex: 1;
    overflow-y: auto;
    padding-right: 3px;
}

.theme-cart-form__items .text-foreground\/75 {
    color: rgba(255, 255, 255, 0.75);
}

.theme-cart-form__items .text-foreground\/70 {
    color: rgba(255, 255, 255, 0.7);
}

.theme-cart-form__items .text-foreground\/60,
.theme-cart-form__items .text-foreground-muted {
    color: rgba(255, 255, 255, 0.6);
}

.theme-cart-form__item-list {
    display: grid;
    gap: 8px;
}

.theme-cart-item {
    display: grid;
    grid-template-columns: 60px minmax(0, 1fr);
    gap: 8px;
    border-bottom: 1px solid rgba(211, 173, 116, 0.22);
    padding-bottom: 8px;
}

.theme-cart-item__media {
    display: grid;
    align-items: center;
    justify-content: center;
    min-height: 60px;
    place-items: center;
    border: 1px solid rgba(211, 173, 116, 0.24);
    background: transparent;
    padding: 2px;
}

.theme-cart-item__picture,
.theme-cart-item__image {
    display: block;
    margin: auto;
    max-width: 100%;
}

.theme-cart-item__image {
    width: auto;
    height: auto;
    max-height: 56px;
    object-fit: contain;
}

.theme-cart-item__content {
    display: grid;
    min-width: 0;
    gap: 6px;
}

.theme-cart-item__header,
.theme-cart-item__footer {
    display: flex;
    align-items: flex-start;
    justify-content: space-between;
    gap: 6px;
}

.theme-cart-item__details {
    min-width: 0;
}

.theme-cart-item__title {
    color: var(--theme-white);
    font-family: var(--font-serif);
    font-size: 12px;
    line-height: 1.25;
    text-transform: uppercase;
}

.theme-cart-item__meta {
    margin-top: 3px;
    color: rgba(255, 255, 255, 0.76);
    font-family: var(--font-sans);
    font-size: 13px;
    line-height: 1.25;
}

.theme-cart-item__option,
.theme-cart-item__discount {
    margin-top: 3px;
    color: rgba(255, 255, 255, 0.62);
    font-family: var(--font-sans);
    font-size: 12px;
    line-height: 1.3;
}

.theme-cart-item__delete {
    display: grid;
    width: 24px;
    height: 24px;
    flex: 0 0 24px;
    place-items: center;
    border: 1px solid rgba(211, 173, 116, 0.45);
    background: transparent;
    color: var(--theme-white);
    transition: border-color 160ms ease, color 160ms ease, opacity 160ms ease;
}

.theme-cart-item__delete:hover {
    border-color: var(--theme-gold);
    color: var(--theme-gold);
}

.theme-cart-item__delete:disabled {
    opacity: 0.5;
}

.theme-cart-item__delete svg {
    width: 13px;
    height: 13px;
    fill: currentColor;
}

.theme-cart-quantity {
    display: inline-flex;
    align-items: center;
    min-height: 28px;
    border: 1px solid rgba(211, 173, 116, 0.45);
    background: rgba(255, 255, 255, 0.03);
}

.theme-cart-quantity__button,
.theme-cart-quantity__input {
    width: 28px;
    height: 26px;
    border: 0;
    background: transparent;
    color: var(--theme-white);
    font-family: var(--font-sans);
    font-size: 12px;
    line-height: 1;
}

.theme-cart-quantity__button {
    display: grid;
    place-items: center;
    transition: color 160ms ease, background-color 160ms ease, opacity 160ms ease;
}

.theme-cart-quantity__button:hover {
    background: rgba(211, 173, 116, 0.18);
    color: var(--theme-gold-soft);
}

.theme-cart-quantity__button:disabled,
.theme-cart-quantity__input:disabled {
    opacity: 0.5;
}

.theme-cart-quantity__input {
    border-right: 1px solid rgba(211, 173, 116, 0.28);
    border-left: 1px solid rgba(211, 173, 116, 0.28);
    text-align: center;
    outline: none;
    appearance: textfield;
}

.theme-cart-quantity__input::-webkit-outer-spin-button,
.theme-cart-quantity__input::-webkit-inner-spin-button {
    margin: 0;
    appearance: none;
}

.theme-cart-quantity__input:focus {
    box-shadow: inset 0 0 0 1px var(--theme-gold);
}

.theme-cart-item__price {
    display: flex;
    flex-wrap: wrap;
    justify-content: flex-end;
    gap: 6px;
    color: var(--theme-gold);
    font-family: var(--font-serif);
    font-size: 14px;
    line-height: 1.2;
    text-align: right;
}

.theme-cart-item__price-old {
    color: rgba(255, 255, 255, 0.52);
    font-size: 11px;
    text-decoration: line-through;
}

.theme-cart-form__items .bg-surface {
    background: transparent !important;
}

.theme-cart-form__items img[src*="/cdn/shop_"] {
    display: block !important;
    width: auto !important;
    height: auto !important;
    max-width: 100% !important;
    max-height: 56px !important;
    margin-inline: auto !important;
    object-fit: contain !important;
}

.theme-cart-form__items .w-1\/3 {
    display: flex !important;
    width: 60px !important;
    flex: 0 0 60px !important;
    align-items: center !important;
    justify-content: center !important;
    padding: 2px !important;
    background: transparent !important;
}

.theme-cart-form__items .max-h-24 {
    max-height: 56px !important;
}

.theme-cart-form__empty {
    display: grid;
    gap: 18px;
}

.theme-cart-rules {
    display: grid;
    gap: 8px;
    margin-bottom: 8px;
    border: 1px solid rgba(211, 173, 116, 0.35);
    background: var(--theme-dark);
    padding: 8px;
}

.theme-cart-rules__source {
    opacity: 0.72;
    font-size: 12px;
}

.theme-cart-rules__label {
    display: flex;
    justify-content: space-between;
    gap: 12px;
    font-size: 13px;
}

.theme-cart-rules__label span:first-child {
    color: var(--theme-gold);
    font-weight: 700;
}

.theme-cart-rules__track {
    height: 4px;
    overflow: hidden;
    background: rgba(255, 255, 255, 0.14);
}

.theme-cart-rules__track div {
    height: 100%;
    background: var(--theme-gold);
}

.theme-cart-form__summary {
    display: grid;
    flex: 0 0 auto;
    gap: 7px;
    border-top: 1px solid var(--theme-gold);
    padding-top: 10px;
    font-size: 13px;
    line-height: 1.2;
}

.theme-cart-form__summary > div {
    display: flex;
    justify-content: space-between;
    gap: 12px;
}

.theme-cart-form__total {
    border-top: 1px solid rgba(211, 173, 116, 0.45);
    padding-top: 8px;
    color: var(--theme-gold);
    font-family: var(--font-serif);
}

.theme-cart-form__summary .theme-button-fill {
    min-height: 36px;
    padding: 8px 14px;
    font-size: 13px;
}

/* Notifications */
#alert {
    position: fixed;
    top: 20px;
    right: 20px;
    z-index: 140;
    display: flex;
    width: min(calc(100vw - 32px), 390px);
    max-width: min(calc(100vw - 32px), 390px);
    flex-direction: column;
    gap: 10px;
    pointer-events: none;
}

#alert > *,
#alert [role="alert"] {
    pointer-events: auto;
}

#alert [role="alert"] {
    display: grid;
    width: 100%;
    max-width: none;
    min-height: 58px;
    grid-template-columns: auto minmax(0, 1fr) auto;
    align-items: flex-start;
    gap: 12px;
    border: 1px solid rgba(211, 173, 116, 0.5);
    border-left: 5px solid var(--theme-gold);
    border-radius: 4px;
    background: rgba(255, 255, 255, 0.97);
    padding: 14px 14px 14px 16px;
    color: var(--theme-black);
    font-family: var(--font-sans);
    box-shadow: 0 18px 44px rgba(0, 0, 0, 0.28);
}

#alert [role="alert"] > div:first-child {
    width: 12px;
    height: 12px;
    margin-top: 4px;
    border-radius: 999px;
    background: var(--theme-gold);
}

#alert [role="alert"] > div:nth-child(2) {
    margin-left: 0;
    color: var(--theme-black);
    font-size: 14px;
    font-weight: 700;
    line-height: 1.45;
}

#alert [role="alert"] > button {
    display: grid;
    width: 30px;
    height: 30px;
    margin: -5px -5px 0 0;
    place-items: center;
    border: 0;
    padding: 6px;
    background: transparent;
    color: rgba(20, 20, 20, 0.68);
    transition: color 160ms ease, background-color 160ms ease;
}

#alert [role="alert"] > button:hover,
#alert [role="alert"] > button:focus-visible {
    background: rgba(20, 20, 20, 0.08);
    color: var(--theme-black);
    outline: none;
}

#alert [role="alert"] > button svg {
    width: 16px;
    height: 16px;
}

#alert [role="alert"]:has(.icon-success) {
    border-left-color: #5d8f63;
}

#alert [role="alert"]:has(.icon-error) {
    border-left-color: #b84a3d;
}

#alert [role="alert"]:has(.icon-warning) {
    border-left-color: #c7852c;
}

#alert [role="alert"]:has(.icon-info) {
    border-left-color: #4f7f9c;
}

#alert .icon-success {
    background: #5d8f63;
}

#alert .icon-error {
    background: #b84a3d;
}

#alert .icon-warning {
    background: #c7852c;
}

#alert .icon-info {
    background: #4f7f9c;
}

body.overflow-hidden #alert {
    top: 72px;
    right: 14px;
    width: min(calc(100vw - 28px), 402px);
    max-width: min(calc(100vw - 28px), 402px);
}

/* Checkout */
body.theme-checkout-shell {
    --color-page: var(--theme-black);
    --color-surface: #252524;
    --color-surface-muted: #30302f;
    --color-foreground: var(--theme-white);
    --color-on-foreground: var(--theme-black);
    --color-accent: var(--theme-gold);
    --color-accent-soft: var(--theme-gold-soft);
    --color-error: #f1b7a6;
    --color-error-border: rgba(241, 183, 166, 0.65);
    --color-error-surface: rgba(94, 35, 28, 0.55);
    --color-error-foreground: #ffd8ce;
    --color-success: #b7d8ba;
    --color-border: rgba(211, 173, 116, 0.35);
    --color-border-strong: rgba(211, 173, 116, 0.72);

    min-height: 100vh;
    background:
        radial-gradient(circle at 15% 0, rgba(211, 173, 116, 0.18), transparent 32rem),
        linear-gradient(180deg, #1a1a19 0, var(--theme-black) 42%);
    color: var(--theme-white);
    color-scheme: dark;
}

.theme-checkout-shell__page {
    min-height: 100vh;
    display: flex;
    flex-direction: column;
}

.theme-checkout-main {
    flex: 1;
    background: transparent;
}

.theme-checkout-header {
    position: relative;
    z-index: 20;
    border-bottom: 1px solid rgba(211, 173, 116, 0.32);
    background: rgba(20, 20, 20, 0.94);
}

.theme-checkout-header__inner {
    display: flex;
    width: min(calc(100% - 32px), var(--theme-container));
    min-height: 86px;
    align-items: center;
    justify-content: space-between;
    gap: 24px;
    margin: 0 auto;
    padding: 12px 0;
}

.theme-checkout-header__brand {
    display: inline-flex;
    align-items: center;
}

.theme-checkout-header__brand img {
    width: auto;
    max-width: 128px;
    height: 64px;
    object-fit: contain;
}

.theme-checkout-header__nav {
    display: flex;
    flex-wrap: wrap;
    justify-content: flex-end;
    gap: 12px;
}

.theme-checkout-header__link {
    display: inline-flex;
    min-height: 38px;
    align-items: center;
    justify-content: center;
    border: 1px solid rgba(211, 173, 116, 0.72);
    padding: 8px 14px;
    color: var(--theme-white);
    font-family: var(--font-serif);
    font-size: 13px;
    font-weight: 700;
    text-transform: uppercase;
    transition: color 160ms ease, background-color 160ms ease, border-color 160ms ease;
}

.theme-checkout-header__link:hover,
.theme-checkout-header__link:focus-visible {
    border-color: var(--theme-white);
    background: var(--theme-white);
    color: var(--theme-black);
    outline: none;
}

.theme-checkout-footer {
    border-top: 1px solid rgba(211, 173, 116, 0.24);
    background: var(--theme-dark);
}

.theme-checkout-footer__inner {
    display: flex;
    width: min(calc(100% - 32px), var(--theme-container));
    align-items: center;
    justify-content: space-between;
    gap: 18px;
    margin: 0 auto;
    padding: 18px 0;
    color: rgba(255, 255, 255, 0.72);
    font-family: var(--font-sans);
    font-size: 12px;
}

.theme-checkout-footer__brand,
.theme-checkout-footer__links {
    display: flex;
    flex-wrap: wrap;
    align-items: center;
}

.theme-checkout-footer__brand {
    gap: 8px 16px;
}

.theme-checkout-footer__links {
    gap: 8px 12px;
}

.theme-checkout-footer__links a {
    color: var(--theme-gold-soft);
    transition: color 160ms ease;
}

.theme-checkout-footer__links a:hover,
.theme-checkout-footer__links a:focus-visible {
    color: var(--theme-white);
    outline: none;
}

.theme-checkout-container {
    width: min(calc(100% - 32px), var(--theme-container));
    margin: 0 auto;
}

.theme-checkout-page {
    padding: 54px 0 72px;
}

.theme-checkout-eyebrow {
    margin: 0 0 10px;
    color: var(--theme-gold);
    font-family: "Josefin Sans", sans-serif;
    font-size: 13px;
    font-weight: 400;
    line-height: 1.4;
    text-transform: uppercase;
}

.theme-checkout-alerts {
    padding-top: 26px;
    transition: opacity 300ms ease;
}

.theme-checkout-alerts .theme-checkout-container {
    display: grid;
    gap: 12px;
}

.theme-checkout-alert {
    border: 1px solid rgba(211, 173, 116, 0.42);
    border-left: 5px solid var(--theme-gold);
    background: rgba(60, 60, 59, 0.94);
    padding: 16px 18px;
    color: var(--theme-white);
    font-family: var(--font-sans);
    transition: opacity 300ms ease;
}

.theme-checkout-alert--error {
    border-color: rgba(241, 183, 166, 0.65);
    border-left-color: #f1b7a6;
}

.theme-checkout-alert__title {
    margin-bottom: 6px;
    color: var(--theme-gold);
    font-family: var(--font-serif);
    font-weight: 700;
    text-transform: uppercase;
}

.theme-checkout-alert p {
    margin: 8px 0 0;
    color: rgba(255, 255, 255, 0.78);
    font-size: 13px;
}

.theme-checkout-confirmation {
    overflow: hidden;
    border: 1px solid rgba(211, 173, 116, 0.46);
    border-left: 5px solid var(--theme-gold);
    background: linear-gradient(145deg, rgba(60, 60, 59, 0.96), rgba(20, 20, 20, 0.98));
    color: var(--theme-white);
}

.theme-checkout-confirmation__header {
    border-bottom: 1px solid rgba(211, 173, 116, 0.35);
    background: rgba(20, 20, 20, 0.34);
    padding: 34px;
}

.theme-checkout-confirmation__header h1,
.theme-checkout-status h1 {
    margin: 0;
    color: var(--theme-white);
    font-family: var(--font-serif);
    font-size: clamp(31px, 4vw, 46px);
    font-weight: 400;
    line-height: 1.12;
    text-transform: uppercase;
}

.theme-checkout-confirmation__header > p:not(.theme-checkout-eyebrow),
.theme-checkout-status p:not(.theme-checkout-eyebrow),
.theme-checkout-guest p:not(.theme-checkout-eyebrow) {
    max-width: 780px;
    margin: 14px 0 0;
    color: rgba(255, 255, 255, 0.78);
    font-size: 15px;
}

.theme-checkout-confirmation__body {
    padding: 34px;
}

.theme-checkout-confirmation__grid {
    display: grid;
    grid-template-columns: minmax(0, 1fr) minmax(300px, 360px);
    gap: 28px;
    align-items: start;
}

.theme-checkout-confirmation__main,
.theme-checkout-card,
.theme-checkout-summary__rows,
.theme-checkout-lines,
.theme-checkout-details {
    display: grid;
    gap: 18px;
}

.theme-checkout-card,
.theme-checkout-summary,
.theme-checkout-guest {
    border: 1px solid rgba(211, 173, 116, 0.28);
    background: rgba(20, 20, 20, 0.34);
    padding: 22px;
}

.theme-checkout-card h2,
.theme-checkout-summary h2,
.theme-checkout-guest h2 {
    margin: 0;
    color: var(--theme-white);
    font-family: var(--font-serif);
    font-size: 22px;
    font-weight: 400;
    line-height: 1.25;
    text-transform: uppercase;
}

.theme-checkout-lines {
    gap: 0;
    border: 1px solid rgba(211, 173, 116, 0.22);
}

.theme-checkout-line {
    display: flex;
    align-items: flex-start;
    justify-content: space-between;
    gap: 18px;
    border-bottom: 1px solid rgba(211, 173, 116, 0.18);
    padding: 14px;
    font-family: var(--font-sans);
}

.theme-checkout-line:last-child {
    border-bottom: 0;
}

.theme-checkout-line > div {
    display: grid;
    gap: 4px;
    min-width: 0;
}

.theme-checkout-line strong {
    color: var(--theme-white);
    font-weight: 700;
}

.theme-checkout-line span {
    color: rgba(255, 255, 255, 0.68);
    font-size: 13px;
}

.theme-checkout-line > strong {
    white-space: nowrap;
}

.theme-checkout-addresses {
    display: grid;
    grid-template-columns: repeat(2, minmax(0, 1fr));
    gap: 24px;
}

.theme-checkout-addresses address {
    display: grid;
    gap: 4px;
    margin-top: 12px;
    color: rgba(255, 255, 255, 0.78);
    font-family: var(--font-sans);
    font-size: 14px;
    font-style: normal;
    line-height: 1.55;
}

.theme-checkout-details {
    gap: 10px;
    margin: 0;
    font-family: var(--font-sans);
}

.theme-checkout-details > div {
    display: grid;
    grid-template-columns: 160px minmax(0, 1fr);
    gap: 14px;
}

.theme-checkout-details dt {
    color: var(--theme-gold);
    font-weight: 700;
}

.theme-checkout-details dd {
    margin: 0;
    color: rgba(255, 255, 255, 0.82);
}

.theme-checkout-summary {
    position: sticky;
    top: 24px;
    background: var(--theme-white);
    color: var(--theme-black);
}

.theme-checkout-summary h2 {
    color: var(--theme-black);
}

.theme-checkout-summary__rows {
    gap: 12px;
    margin: 20px 0;
    font-family: var(--font-sans);
}

.theme-checkout-summary__rows > div {
    display: flex;
    justify-content: space-between;
    gap: 12px;
    color: rgba(20, 20, 20, 0.76);
}

.theme-checkout-summary__total {
    border-top: 1px solid rgba(20, 20, 20, 0.18);
    padding-top: 14px;
    color: var(--theme-black) !important;
    font-family: var(--font-serif);
    font-size: 19px;
    text-transform: uppercase;
}

.theme-checkout-actions {
    display: flex;
    flex-wrap: wrap;
    gap: 12px;
    margin-top: 28px;
}

.theme-checkout-guest {
    display: grid;
    grid-template-columns: minmax(0, 1fr) auto;
    gap: 24px;
    align-items: center;
    margin-top: 28px;
}

.theme-checkout-instructions {
    border: 1px solid rgba(211, 173, 116, 0.24);
    background: rgba(20, 20, 20, 0.46);
    padding: 16px;
    color: rgba(255, 255, 255, 0.8);
    font-family: var(--font-sans);
    font-size: 14px;
    line-height: 1.7;
}

.theme-checkout-instructions p {
    margin: 0 0 10px;
}

.theme-checkout-status {
    display: grid;
    min-height: min(620px, calc(100vh - 176px));
    place-items: center;
    padding: 54px 16px 72px;
}

.theme-checkout-status__card {
    width: min(100%, 680px);
    border: 1px solid rgba(211, 173, 116, 0.46);
    border-left: 5px solid var(--theme-gold);
    background: linear-gradient(145deg, rgba(60, 60, 59, 0.96), rgba(20, 20, 20, 0.98));
    padding: 42px;
    text-align: center;
}

.theme-checkout-status .theme-checkout-actions {
    justify-content: center;
}

.theme-checkout-status__reference,
.theme-checkout-status__error {
    color: var(--theme-gold) !important;
    font-weight: 700;
}

.theme-checkout-spinner {
    width: 52px;
    height: 52px;
    margin: 0 auto 26px;
    border: 2px solid rgba(211, 173, 116, 0.28);
    border-top-color: var(--theme-gold);
    border-radius: 50%;
    animation: theme-checkout-spin 1s linear infinite;
}

@keyframes theme-checkout-spin {
    to {
        transform: rotate(360deg);
    }
}

.theme-checkout-shell .opacity-0 {
    opacity: 0;
}

.theme-checkout-shell .bg-page,
.theme-checkout-shell .bg-checkout-glow {
    background: transparent;
}

.theme-checkout-shell [data-controller~="live"] > section {
    background:
        radial-gradient(circle at 18% 0, rgba(211, 173, 116, 0.16), transparent 34rem),
        var(--theme-black);
    color: var(--theme-white);
}

.theme-checkout-shell .bg-accent,
.theme-checkout-shell .hover\:bg-accent:hover {
    background-color: var(--theme-gold);
}

.theme-checkout-shell .hover\:bg-accent-soft:hover {
    background-color: var(--theme-gold-soft);
}

.theme-checkout-shell .bg-accent\/5 {
    background-color: rgba(211, 173, 116, 0.05);
}

.theme-checkout-shell .bg-accent\/10 {
    background-color: rgba(211, 173, 116, 0.1);
}

.theme-checkout-shell .bg-foreground {
    background-color: var(--theme-white);
    color: var(--theme-black);
}

.theme-checkout-shell .bg-foreground\/20 {
    background-color: rgba(255, 255, 255, 0.2);
}

.theme-checkout-shell .bg-foreground\/5,
.theme-checkout-shell .bg-foreground\/\[0\.02\] {
    background-color: rgba(255, 255, 255, 0.06);
}

.theme-checkout-shell .bg-surface,
.theme-checkout-shell .bg-surface\/80,
.theme-checkout-shell .bg-surface\/70,
.theme-checkout-shell .bg-surface\/50 {
    background-color: rgba(60, 60, 59, 0.94);
}

.theme-checkout-shell .bg-surface\/30,
.theme-checkout-shell .bg-surface\/10,
.theme-checkout-shell .bg-surface\/5 {
    background-color: rgba(20, 20, 20, 0.26);
}

.theme-checkout-shell .bg-surface-muted {
    background-color: rgba(60, 60, 59, 0.74);
}

.theme-checkout-shell .text-foreground,
.theme-checkout-shell .text-foreground\/90,
.theme-checkout-shell .text-foreground\/80,
.theme-checkout-shell .text-foreground\/75,
.theme-checkout-shell .text-foreground\/70,
.theme-checkout-shell .text-foreground\/60,
.theme-checkout-shell .text-foreground\/55,
.theme-checkout-shell .text-foreground-muted {
    color: rgba(255, 255, 255, 0.9);
}

.theme-checkout-shell .text-foreground\/75,
.theme-checkout-shell .text-foreground\/70 {
    color: rgba(255, 255, 255, 0.72);
}

.theme-checkout-shell .text-foreground\/60,
.theme-checkout-shell .text-foreground\/55,
.theme-checkout-shell .text-foreground-muted {
    color: rgba(255, 255, 255, 0.6);
}

.theme-checkout-shell .bg-foreground .text-on-foreground,
.theme-checkout-shell .bg-foreground .text-on-foreground\/90,
.theme-checkout-shell .bg-foreground .text-on-foreground\/85,
.theme-checkout-shell .bg-foreground .text-on-foreground\/80,
.theme-checkout-shell .bg-foreground .text-on-foreground\/55,
.theme-checkout-shell .bg-foreground .text-foreground,
.theme-checkout-shell .bg-foreground .text-foreground\/90,
.theme-checkout-shell .bg-foreground .text-foreground\/75,
.theme-checkout-shell .bg-foreground .text-foreground\/60 {
    color: rgba(20, 20, 20, 0.82);
}

.theme-checkout-shell .text-on-foreground {
    color: var(--theme-black);
}

.theme-checkout-shell .text-on-foreground\/90,
.theme-checkout-shell .text-on-foreground\/85,
.theme-checkout-shell .text-on-foreground\/80,
.theme-checkout-shell .text-on-foreground\/55 {
    color: rgba(20, 20, 20, 0.72);
}

.theme-checkout-shell .text-accent,
.theme-checkout-shell .text-accent\/90,
.theme-checkout-shell .text-accent\/80,
.theme-checkout-shell .hover\:text-accent:hover {
    color: var(--theme-gold);
}

.theme-checkout-shell .bg-foreground .text-accent,
.theme-checkout-shell .bg-foreground .text-accent\/90,
.theme-checkout-shell .bg-foreground .text-accent\/80 {
    color: #9b7442;
}

.theme-checkout-shell .text-error,
.theme-checkout-shell .text-error-foreground {
    color: #ffd8ce;
}

.theme-checkout-shell .text-success {
    color: #b7d8ba;
}

.theme-checkout-shell .border-accent,
.theme-checkout-shell .border-accent\/60,
.theme-checkout-shell .border-accent\/40,
.theme-checkout-shell .border-accent\/30,
.theme-checkout-shell .border-accent\/25,
.theme-checkout-shell .border-accent\/20,
.theme-checkout-shell .border-accent\/15,
.theme-checkout-shell .border-accent\/10,
.theme-checkout-shell .border-on-foreground\/10,
.theme-checkout-shell .border-on-foreground\/20,
.theme-checkout-shell .border-foreground\/10 {
    border-color: rgba(211, 173, 116, 0.36);
}

.theme-checkout-shell .border-l-accent\/80 {
    border-left-color: var(--theme-gold);
}

.theme-checkout-shell .border-error-border {
    border-color: rgba(241, 183, 166, 0.65);
}

.theme-checkout-shell .shadow-surface,
.theme-checkout-shell .shadow-sm {
    box-shadow: 0 24px 70px rgba(0, 0, 0, 0.2);
}

.theme-checkout-shell .shadow-surface-strong {
    box-shadow: 0 32px 90px rgba(0, 0, 0, 0.34);
}

.theme-checkout-shell .shadow-promo-line {
    box-shadow: inset 4px 0 0 rgba(211, 173, 116, 0.72);
}

.theme-checkout-shell h1,
.theme-checkout-shell h2,
.theme-checkout-shell h3 {
    font-weight: 400;
}

.theme-checkout-shell .font-semibold,
.theme-checkout-shell .font-medium {
    font-weight: 700;
}

.theme-checkout-shell .tracking-label,
.theme-checkout-shell .tracking-card-title,
.theme-checkout-shell .tracking-form-label {
    letter-spacing: 0;
}

.theme-checkout-shell .text-caption {
    font-size: 11px;
}

.theme-checkout-shell input:not([type="hidden"]):not([type="checkbox"]):not([type="radio"]),
.theme-checkout-shell select,
.theme-checkout-shell textarea {
    width: 100%;
    border: 1px solid rgba(211, 173, 116, 0.55);
    border-radius: 0;
    background: rgba(20, 20, 20, 0.5);
    color: var(--theme-white);
    font-family: var(--font-sans);
    box-shadow: none;
}

.theme-checkout-shell input:not([type="hidden"]):not([type="checkbox"]):not([type="radio"])::placeholder,
.theme-checkout-shell textarea::placeholder {
    color: rgba(255, 255, 255, 0.5);
}

.theme-checkout-shell input:not([type="hidden"]):not([type="checkbox"]):not([type="radio"]):focus,
.theme-checkout-shell select:focus,
.theme-checkout-shell textarea:focus {
    border-color: var(--theme-gold);
    outline: 2px solid rgba(211, 173, 116, 0.22);
    outline-offset: 2px;
}

.theme-checkout-shell input[type="checkbox"],
.theme-checkout-shell input[type="radio"] {
    accent-color: var(--theme-gold);
}

.theme-checkout-shell option {
    background: var(--theme-dark);
    color: var(--theme-white);
}

.theme-checkout-shell label {
    color: var(--theme-gold);
    font-family: "Josefin Sans", sans-serif;
    font-weight: 400;
}

.theme-checkout-shell .bg-foreground input:not([type="hidden"]):not([type="checkbox"]):not([type="radio"]),
.theme-checkout-shell .bg-foreground select,
.theme-checkout-shell .bg-foreground textarea {
    border-color: rgba(20, 20, 20, 0.2);
    background: rgba(20, 20, 20, 0.05);
    color: var(--theme-black);
}

.theme-checkout-shell .bg-foreground input:not([type="hidden"]):not([type="checkbox"]):not([type="radio"])::placeholder,
.theme-checkout-shell .bg-foreground textarea::placeholder {
    color: rgba(20, 20, 20, 0.5);
}

.theme-checkout-shell .bg-foreground option {
    background: var(--theme-white);
    color: var(--theme-black);
}

.theme-checkout-shell .theme-checkout-order-summary {
    overflow: hidden;
    border: 1px solid rgba(211, 173, 116, 0.46);
    border-left: 5px solid var(--theme-gold);
    border-radius: 0;
    background: linear-gradient(145deg, rgba(60, 60, 59, 0.96), rgba(20, 20, 20, 0.98));
    color: var(--theme-white);
    box-shadow: 0 30px 80px rgba(0, 0, 0, 0.34);
}

.theme-checkout-shell .theme-checkout-order-summary--desktop {
    width: 100%;
}

.theme-checkout-shell .theme-checkout-order-summary__toggle,
.theme-checkout-shell .theme-checkout-order-summary__header {
    border-color: rgba(211, 173, 116, 0.34);
    background: rgba(20, 20, 20, 0.32);
}

.theme-checkout-shell .theme-checkout-order-summary__toggle {
    min-height: 104px;
}

.theme-checkout-shell .theme-checkout-order-summary__body {
    border-color: rgba(211, 173, 116, 0.28);
}

.theme-checkout-shell .theme-checkout-order-summary__eyebrow,
.theme-checkout-shell .theme-checkout-order-promo__label {
    color: var(--theme-gold) !important;
    font-family: "Josefin Sans", sans-serif;
    font-size: 12px;
    font-weight: 400;
    line-height: 1.4;
}

.theme-checkout-shell .theme-checkout-order-summary__title {
    color: var(--theme-white) !important;
    font-family: var(--font-serif);
    font-weight: 400;
    line-height: 1.25;
}

.theme-checkout-shell .theme-checkout-order-summary__amount {
    color: var(--theme-gold-soft) !important;
    font-family: var(--font-serif);
}

.theme-checkout-shell .theme-checkout-order-summary__button {
    border-color: rgba(211, 173, 116, 0.72);
    color: var(--theme-white) !important;
    font-family: var(--font-serif);
    font-weight: 700;
    transition: color 160ms ease, background-color 160ms ease, border-color 160ms ease;
}

.theme-checkout-shell .theme-checkout-order-summary__button:hover,
.theme-checkout-shell .theme-checkout-order-summary__toggle:focus-visible .theme-checkout-order-summary__button {
    border-color: var(--theme-white);
    background: var(--theme-white);
    color: var(--theme-black) !important;
}

.theme-checkout-shell .theme-checkout-order-summary .text-on-foreground,
.theme-checkout-shell .theme-checkout-order-summary .text-on-foreground\/90,
.theme-checkout-shell .theme-checkout-order-summary .text-on-foreground\/85,
.theme-checkout-shell .theme-checkout-order-summary .text-on-foreground\/80,
.theme-checkout-shell .theme-checkout-order-summary .text-on-foreground\/55 {
    color: rgba(255, 255, 255, 0.78);
}

.theme-checkout-shell .theme-checkout-order-line {
    border: 1px solid rgba(211, 173, 116, 0.22);
    border-radius: 0;
    background: rgba(20, 20, 20, 0.26);
    padding: 12px !important;
    color: var(--theme-white);
}

.theme-checkout-shell .theme-checkout-order-line--gift {
    border-color: rgba(211, 173, 116, 0.45) !important;
    border-left: 4px solid var(--theme-gold) !important;
    border-radius: 0 !important;
    background: rgba(211, 173, 116, 0.12) !important;
}

.theme-checkout-shell .theme-checkout-order-line__media {
    width: 88px;
    height: 128px;
    border-color: rgba(211, 173, 116, 0.28) !important;
    background: rgba(255, 255, 255, 0.06) !important;
}

.theme-checkout-shell .theme-checkout-order-line__media picture {
    display: flex;
    width: 100%;
    height: 100%;
    align-items: center;
    justify-content: center;
}

.theme-checkout-shell .theme-checkout-order-line__media img {
    width: auto;
    height: 100%;
    max-width: 100%;
    max-height: 124px;
    object-fit: contain;
}

.theme-checkout-shell .theme-checkout-order-line__title {
    margin-top: 0 !important;
    color: var(--theme-white) !important;
    font-family: var(--font-serif);
    font-size: 14px;
    font-weight: 400;
    line-height: 1.28;
}

.theme-checkout-shell .theme-checkout-order-line__meta,
.theme-checkout-shell .theme-checkout-order-line__option,
.theme-checkout-shell .theme-checkout-order-line__quantity {
    color: rgba(255, 255, 255, 0.68) !important;
    font-family: var(--font-sans);
}

.theme-checkout-shell .theme-checkout-order-line__price {
    color: var(--theme-white) !important;
    font-family: var(--font-serif);
    font-weight: 700;
    white-space: nowrap;
}

.theme-checkout-shell .theme-checkout-order-line__price-old {
    color: rgba(255, 255, 255, 0.46) !important;
}

.theme-checkout-shell .theme-checkout-order-line__discount,
.theme-checkout-shell .theme-checkout-order-line__placeholder {
    color: var(--theme-gold-soft) !important;
}

.theme-checkout-shell .theme-checkout-order-promo {
    border-color: rgba(211, 173, 116, 0.32);
    background: rgba(211, 173, 116, 0.07) !important;
}

.theme-checkout-shell .theme-checkout-order-promo__input {
    min-height: 46px;
    border-color: rgba(211, 173, 116, 0.46) !important;
    background: rgba(20, 20, 20, 0.48) !important;
    color: var(--theme-white) !important;
}

.theme-checkout-shell .theme-checkout-order-promo__input::placeholder {
    color: rgba(255, 255, 255, 0.5) !important;
}

.theme-checkout-shell .theme-checkout-order-promo__button {
    min-height: 46px;
    border-color: rgba(211, 173, 116, 0.72) !important;
    padding: 0 14px;
    color: var(--theme-gold) !important;
    font-family: var(--font-serif);
    font-weight: 700;
}

.theme-checkout-shell .theme-checkout-order-promo__button:hover,
.theme-checkout-shell .theme-checkout-order-promo__button:focus-visible {
    border-color: var(--theme-white) !important;
    background: var(--theme-white) !important;
    color: var(--theme-black) !important;
    outline: none;
}

.theme-checkout-shell .theme-checkout-order-totals {
    border-color: rgba(211, 173, 116, 0.3) !important;
    color: rgba(255, 255, 255, 0.78);
    font-family: var(--font-sans);
}

.theme-checkout-shell .theme-checkout-order-totals > div {
    gap: 18px;
}

.theme-checkout-shell .theme-checkout-order-totals .text-accent,
.theme-checkout-shell .theme-checkout-order-totals .text-accent\/80 {
    color: var(--theme-gold-soft) !important;
}

.theme-checkout-shell .theme-checkout-order-total {
    border-color: rgba(211, 173, 116, 0.42) !important;
    color: var(--theme-white) !important;
    font-family: var(--font-serif);
    font-size: 20px;
    font-weight: 400;
}

.theme-checkout-shell .theme-checkout-order-total span:last-child {
    color: var(--theme-gold-soft);
    font-weight: 700;
}

.theme-checkout-shell .theme-checkout-order-paid,
.theme-checkout-shell .theme-checkout-order-mobile-action {
    border-color: rgba(211, 173, 116, 0.38);
    border-radius: 0;
    background: rgba(20, 20, 20, 0.36) !important;
    color: rgba(255, 255, 255, 0.8) !important;
}

.theme-checkout-shell .theme-checkout-order-pay {
    display: flex;
    min-height: 50px;
    align-items: center;
    justify-content: center;
    border: 1px solid var(--theme-gold);
    background: var(--theme-gold) !important;
    color: var(--theme-black) !important;
    font-family: var(--font-serif);
    font-weight: 700;
    line-height: 1.2;
    transition: color 160ms ease, background-color 160ms ease, border-color 160ms ease;
}

.theme-checkout-shell .theme-checkout-order-pay:hover,
.theme-checkout-shell .theme-checkout-order-pay:focus-visible {
    border-color: var(--theme-white);
    background: var(--theme-white) !important;
    color: var(--theme-black) !important;
    outline: none;
}

.theme-checkout-shell .theme-checkout-order-pay:disabled {
    border-color: rgba(255, 255, 255, 0.2);
    background: rgba(255, 255, 255, 0.12) !important;
    color: rgba(255, 255, 255, 0.46) !important;
}

.theme-checkout-shell .theme-checkout-order-secure {
    color: rgba(255, 255, 255, 0.72) !important;
}

.theme-checkout-shell .theme-checkout-order-secure .bg-accent {
    background: var(--theme-gold);
}

.theme-checkout-shell [data-controller~="live"] .theme-shop-partner {
    max-width: none;
}

.theme-checkout-shell [data-controller~="live"] .theme-shop-partner__panel {
    background: rgba(60, 60, 59, 0.94);
}

.theme-checkout-shell [data-controller~="live"] .theme-shop-legal-notice__inner {
    border-color: rgba(211, 173, 116, 0.38);
}

.theme-checkout-shell [data-controller~="live"] form > .border-accent\/30,
.theme-checkout-shell [data-controller~="live"] form > .grid .border-accent\/30 {
    border-left: 5px solid var(--theme-gold);
}

@media (min-width: 1024px) {
    .theme-checkout-shell .hidden.lg\:block {
        display: block !important;
    }

    .theme-checkout-shell .hidden.lg\:flex {
        display: flex !important;
    }

    .theme-checkout-shell .lg\:grid-cols-checkout {
        grid-template-columns: minmax(0, 1fr) minmax(360px, 420px);
    }

    .theme-checkout-shell .lg\:grid-cols-order-summary,
    .theme-checkout-shell .lg\:grid-cols-offline-payment {
        grid-template-columns: minmax(0, 1fr) minmax(300px, 360px);
    }

    .theme-checkout-shell .lg\:grid-cols-inline-action {
        grid-template-columns: minmax(0, 1fr) auto;
    }
}

@media (max-width: 1024px) {
    .theme-checkout-confirmation__grid,
    .theme-checkout-guest {
        grid-template-columns: 1fr;
    }

    .theme-checkout-summary {
        position: static;
    }
}

@media (max-width: 720px) {
    .theme-checkout-header__inner,
    .theme-checkout-footer__inner {
        width: calc(100% - 24px);
    }

    .theme-checkout-header__inner,
    .theme-checkout-footer__inner,
    .theme-checkout-addresses,
    .theme-checkout-details > div {
        grid-template-columns: 1fr;
    }

    .theme-checkout-header__inner,
    .theme-checkout-footer__inner {
        align-items: center;
        text-align: center;
    }

    .theme-checkout-header__inner {
        flex-direction: column;
    }

    .theme-checkout-footer__inner {
        flex-direction: column;
    }

    .theme-checkout-footer__brand,
    .theme-checkout-footer__links {
        justify-content: center;
    }

    .theme-checkout-page,
    .theme-checkout-status {
        padding: 34px 0 52px;
    }

    .theme-checkout-status {
        padding-right: 12px;
        padding-left: 12px;
    }

    .theme-checkout-confirmation__header,
    .theme-checkout-confirmation__body,
    .theme-checkout-status__card {
        padding: 24px;
    }

    .theme-checkout-line {
        flex-direction: column;
        gap: 8px;
    }

    .theme-checkout-actions,
    .theme-checkout-actions > * {
        width: 100%;
    }
}

/* Footer */
#footer {
    position: relative;
    background: var(--theme-dark);
}

.theme-footer {
    position: relative;
    overflow: hidden;
    background: var(--theme-dark);
    color: var(--theme-white);
}

.theme-footer__media {
    position: absolute;
    inset: 0;
    z-index: -1;
    background-repeat: no-repeat;
    background-position: 50% 25%;
    background-size: cover;
}

.theme-footer__media .theme-background-image {
    position: absolute;
    inset: 0;
    display: block;
    overflow: hidden;
}

.theme-footer__media .theme-background-image picture,
.theme-footer__media .theme-background-image img {
    width: 100%;
    height: 100%;
}

.theme-footer__media .theme-background-image img {
    object-fit: cover;
    object-position: 50% 25%;
}

.theme-footer__content {
    position: relative;
    z-index: 1;
    display: grid;
    grid-template-columns: repeat(3, minmax(0, 1fr));
    align-items: center;
    gap: 34px;
    padding: 10px;
}

.theme-footer__menu {
    display: grid;
    gap: 4px;
    font-family: var(--font-serif);
    text-transform: uppercase;
}

.theme-footer__contact {
    display: block;
    padding: 0 15px;
    text-align: center;
}

.theme-footer .theme-social-links {
    position: static;
    display: block;
    width: auto;
    height: 42.5938px;
    margin: 5px 0 20px;
    padding: 0;
    color: var(--theme-white);
    line-height: 25.6px;
    text-align: center;
    text-transform: uppercase;
}

.theme-footer .theme-social-links li {
    position: relative;
    display: inline-block;
    width: 35px;
    height: 35px;
    margin: 0 5px 0 0;
    border: 1px solid var(--theme-white);
    border-radius: 50px;
    font-family: Roboto, sans-serif;
    font-weight: 400;
    line-height: 25.6px;
    list-style: none;
    text-align: center;
    vertical-align: top;
}

.theme-footer .theme-social-links li:hover {
    background: var(--theme-white);
}

.theme-footer .theme-social-link {
    position: absolute;
    top: 50%;
    right: 0;
    left: 0;
    display: block;
    width: 33px;
    height: 25.5938px;
    margin: 0 auto;
    border: 0;
    border-radius: 0;
    color: var(--theme-white);
    font-family: Roboto, sans-serif;
    font-weight: 400;
    line-height: 25.6px;
    transform: translateY(-50%);
}

.theme-footer .theme-social-links li:hover .theme-social-link {
    color: var(--theme-dark);
}

.theme-footer .theme-social-link svg {
    display: inline-block;
    width: 12.4531px;
    height: 16px;
    fill: currentColor;
    vertical-align: middle;
}

.theme-footer__contact > .theme-button-stroke {
    display: inline;
    width: auto;
    height: auto;
    min-height: 0;
    box-sizing: border-box;
    border: 1px solid var(--theme-white);
    padding: 10px 15px;
    color: var(--theme-white);
    font-family: "Museo Slab", serif;
    font-size: 16px;
    font-weight: 500;
    line-height: 24px;
    text-align: center;
    text-transform: uppercase;
}

.theme-footer__contact > .theme-button-stroke:hover,
.theme-footer__contact > .theme-button-stroke:focus {
    background: var(--theme-white);
    color: var(--theme-dark);
}

.theme-footer__address {
    display: grid;
    justify-items: center;
    margin: 0;
    text-align: center;
    font-style: normal;
}

.theme-footer__address img {
    width: 60px;
    margin-bottom: 12px;
}

.theme-footer__address p {
    margin: 0;
    line-height: 1.6;
}

.theme-footer__legals {
    grid-column: 1 / -1;
    margin-top: 20px;
    text-align: center;
    font-family: var(--font-serif);
}

.theme-footer__drinking {
    position: relative;
    z-index: 1;
    background: #000;
    padding: 5px;
    text-align: center;
}

.theme-footer__drinking p {
    margin: 0;
    font-family: "Josefin Sans", sans-serif;
    font-size: 16px;
    font-weight: 300;
}

@media (max-width: 1024px) {
    .theme-homepage-grid,
    .theme-home-grid {
        grid-template-columns: 1fr;
    }

    .theme-home-row {
        grid-template-columns: 1fr;
    }

    .theme-homepage-content-5,
    .theme-discover-link,
    .theme-homepage-shop-image,
    .theme-homepage-shop-text,
    .theme-home-title-panel,
    .theme-home-image-panel,
    .theme-home-title-panel--right,
    .theme-home-image-panel--left {
        grid-column: 1 / -1;
    }

    .theme-home-cell,
    .theme-home-cell--5,
    .theme-home-cell--7,
    .theme-home-cell--full,
    .theme-home-cell--left,
    .theme-home-cell--right {
        grid-column: 1 / -1;
    }

    .theme-history-title.theme-title-right {
        width: 100%;
        transform: none;
    }

    .theme-homepage-cuvee-row,
    .theme-homepage-cuvee-title-back {
        grid-template-columns: 1fr;
    }

    .theme-homepage-shop-image,
    .theme-homepage-shop-text,
    .theme-homepage-contact-content {
        grid-row: auto;
        width: auto;
        margin-top: 0;
        justify-self: stretch;
    }

    .theme-homepage-cuvee-content {
        min-height: auto;
    }

    .theme-homepage-cuvee-title-back {
        position: relative;
        bottom: auto;
        margin-top: -80px;
    }

    .theme-homepage-cuvee-title-back h3,
    .theme-homepage-cuvee-title-back span {
        text-align: center;
    }

    .theme-homepage-cuvee-text {
        padding-left: 0;
        text-align: center;
    }

    .theme-homepage-cuvee-text p {
        margin-right: auto;
        margin-left: auto;
    }

    .theme-old-pictures {
        grid-template-columns: repeat(6, minmax(0, 1fr));
    }

    .theme-old-pictures .theme-landscape {
        grid-column: span 3 / span 3;
    }

    .theme-old-pictures .theme-landscape-max {
        grid-column: span 4 / span 4;
    }

    .theme-old-pictures .theme-portrait {
        grid-column: span 2 / span 2;
    }

    .theme-shop-information-grid--2,
    .theme-shop-information-grid--3 {
        grid-template-columns: 1fr;
    }

    .theme-shop-product-grid {
        grid-template-columns: repeat(2, minmax(0, 1fr));
    }
}

@media (max-width: 720px) {
    .theme-page {
        padding: 52px 0;
    }

    .theme-homepage-page {
        padding: 0;
    }

    .theme-header-nav-simple {
        height: 90vh;
        margin-top: 20px;
        margin-bottom: 0;
    }

    .theme-navbar-nav-simple .theme-menu-logo img {
        width: 180px;
        max-width: 180px;
        height: 100px;
    }

    .theme-navbar-nav-simple nav {
        top: 20px;
        width: 30px;
        height: auto;
    }

    .theme-menu-picto {
        width: 30px;
        height: 30px;
        padding: 10px 0;
    }

    .theme-menu-labels {
        gap: 6px;
        margin: 10px auto;
    }

    .theme-menu-labels .theme-nav-open {
        width: 30px;
        height: 28px;
    }

    .theme-nav-actions {
        gap: 6px;
    }

    .theme-language-switcher {
        width: 28px;
        font-size: 8px;
    }

    .theme-nav-open__lines,
    .theme-nav-open__lines i {
        width: 15px;
    }

    .theme-nav-icon-button {
        width: 28px;
        height: 28px;
    }

    .theme-nav-icon-button__icon {
        width: 15px;
        height: 15px;
    }

    .theme-nav-cart__count {
        top: -6px;
        right: -5px;
        min-width: 15px;
        height: 15px;
        font-size: 9px;
    }

    .theme-nav-container {
        padding: 0;
    }

    .theme-nav-container > .theme-container {
        position: relative;
        top: 0;
        width: 100%;
        margin: 0;
        padding: 20px;
        transform: none;
    }

    .theme-hero {
        height: 70vh;
        min-height: 400px;
        margin-top: 0;
    }

    .theme-hero .theme-hero-titles {
        width: calc(100% - 20px);
    }

    .theme-hero h1 {
        display: none;
    }

    .theme-hero h2 {
        font-size: 22px;
    }

    .theme-hero h2 span {
        font-size: 28px;
    }

    .theme-scroll-indicator {
        bottom: 30px;
    }

    .theme-scroll-indicator svg {
        bottom: -80px;
        height: 60px;
    }

    .theme-menu-grid {
        grid-template-columns: repeat(auto-fit, minmax(300px, 1fr));
    }

    .theme-homepage-grid,
    .theme-home-grid {
        gap: 0;
    }

    .theme-homepage-page .theme-container {
        width: 100%;
    }

    .theme-home-page.theme-page .theme-container {
        width: 100%;
    }

    .theme-homepage-grid > * {
        margin: 10px;
        padding: 10px 0;
    }

    .theme-home-cell {
        margin: 10px;
        padding: 10px;
    }

    .theme-picture--landscape {
        height: 350px;
    }

    .theme-home-picture--panel,
    .theme-home-picture--wide {
        height: 350px;
    }

    .theme-history-title {
        width: 100%;
        padding: 20px 10px;
        font-size: 19px;
        line-height: 26.6px;
    }

    .theme-homepage-contact-content h3 {
        font-size: 19px;
        line-height: 26.6px;
    }

    .theme-home-title-panel--right {
        order: -1;
    }

    .theme-home-image-panel--left {
        order: 0;
    }

    .theme-homepage-cuvee-content {
        min-height: 668px;
        margin: 10px;
        padding: 10px 0;
    }

    .theme-homepage-cuvee-title-back {
        position: absolute;
        top: 50%;
        right: 0;
        bottom: auto;
        left: 0;
        display: flex;
        flex-wrap: wrap;
        min-height: 211px;
        align-items: center;
        justify-content: center;
        margin-top: 0;
        transform: translateY(-50%);
    }

    .theme-homepage-cuvee-title-back > div {
        flex: 0 0 auto;
        width: calc(100% - 20px);
        margin: 10px;
        padding: 10px 0;
    }

    .theme-homepage-cuvee-title-back h3 {
        position: relative;
        z-index: 0;
        width: 80%;
        padding: 0 10px;
        font-size: 19px;
        font-weight: 400;
        line-height: 26.6px;
        text-align: left;
    }

    .theme-homepage-cuvee-title-back h3::before {
        position: absolute;
        top: 50%;
        right: 0;
        left: 0;
        z-index: -1;
        content: "";
        background: var(--theme-gold);
        padding: 40px;
        transform: translateY(-50%);
    }

    .theme-homepage-cuvee-title-back span {
        display: inline-block;
        width: 60%;
        font-size: 2em;
        line-height: 1;
        text-align: left;
    }

    .theme-homepage-contact-content a + a {
        margin-top: 12px;
        margin-left: 0;
    }

    .theme-split-text {
        column-count: 1;
        text-align: left;
    }

    .theme-cuvee-item-img a {
        display: inline-block;
    }

    .theme-cuvee-item-picture__image {
        max-height: 300px;
    }

    .theme-cuvee-item-square {
        top: 70%;
        left: -30px;
        width: 30px;
        height: 70px;
    }

    .theme-cuvee-detail__content {
        grid-template-columns: 1fr;
        gap: 28px;
    }

    .theme-cuvee-detail__media {
        order: -1;
        min-height: 360px;
    }

    .theme-cuvee-detail__image {
        max-height: 360px;
    }

    .theme-cuvee-detail__square {
        left: -16px;
        z-index: 3;
        width: 30px;
        height: 86px;
    }

    .theme-cuvee-detail__technical-row {
        grid-template-columns: 1fr;
        gap: 2px;
    }

    .theme-shop-product-card__media {
        min-height: 250px;
    }

    .theme-shop-product-grid {
        grid-template-columns: 1fr;
    }

    .theme-shop-product-card__media .product-gallery,
    .theme-shop-product-card__media .splide__track,
    .theme-shop-product-card__media .splide__list,
    .theme-shop-product-card__media .splide__slide,
    .theme-shop-product-card__image,
    .theme-shop-product-card__image-row,
    .theme-shop-product-card__image-element {
        height: 250px;
    }

    .theme-shop-partner__form,
    .theme-shop-product-card__fields,
    .theme-footer__content {
        grid-template-columns: 1fr;
    }

    .theme-shop-legal-notice__inner {
        align-items: flex-start;
        gap: 16px;
        padding: 16px;
    }

    .theme-shop-partner__form {
        display: grid;
    }

    .theme-shop-partner__panel--active {
        grid-template-columns: auto minmax(0, 1fr);
        gap: 14px;
        padding: 20px;
    }

    .theme-shop-partner__status {
        width: 40px;
        height: 40px;
    }

    .theme-shop-partner__reset {
        width: 100%;
        grid-column: 1 / -1;
    }

    .theme-shop-blocked {
        grid-template-columns: 1fr;
        gap: 18px;
        padding: 24px 20px 26px 24px;
    }

    .theme-shop-blocked__icon {
        width: 48px;
        height: 48px;
    }

    .theme-shop-blocked__icon svg {
        width: 27px;
        height: 27px;
    }

    .theme-shop-blocked__contact {
        align-items: stretch;
        flex-direction: column;
        gap: 16px;
    }

    .theme-shop-blocked__contact .theme-button-fill {
        width: 100%;
    }

    .theme-shop-product-card__meta {
        flex-direction: column;
    }

    .theme-shop-product-card__price {
        text-align: left;
    }

    .theme-shop-quantity {
        grid-template-columns: minmax(0, 1fr) auto;
    }

    .theme-shop-quantity__input {
        position: absolute;
        width: 1px;
        min-width: 1px;
        height: 1px;
        overflow: hidden;
        opacity: 0;
    }

    .theme-shop-quantity__stepper {
        display: flex;
    }

    .theme-footer__content {
        text-align: center;
    }

    .theme-footer__contact {
        margin: 20px 0;
        padding: 0 10px;
    }
}
